window.Gleam.initSearch([{"doc":"sketch","title":"sketch","content":"# Sketch\n\nSketch is a module providing CSS-in-Gleam in its simpler form. Sketch does not\ntry to add complicated API on top of CSS. If you have CSS knowledge, you&#39;ll feel\nright at home, with all the niceties offered by Sketch, i.e. type-checking of\nsizes and push-to-browser stylesheets of your classes, as well as SSR support.\n\nSketch supports both runtime of Gleam, and will let you write your CSS without\nover-thinking about it. Let Sketch handle the hard task for you of CSS caching,\ngeneration and pushing it in the browser. Sketch do the right choices for you,\nto maximise performance in the browser and on BEAM.\n\n## Distributions\n\nSketch is thought as bare package, built as a foundation for every CSS packages\nthat want to leverage on it. In the Sketch package, you&#39;ll find all CSS\nproperties accessible, as well as low level generation functions, to go from\nSketch to CSS. Sketch package is also made for framework developers, to provide\na common basement, reusable across the entire Gleam ecosystem, letting users\nreuse their knowledge no matter what they are coding.\n\nSketch already supports two compilation target:\n[Lustre](https://hexdocs.pm/lustre/), with\n[`sketch_lustre`](https://hexdocs.pm/sketch_lustre/), and pure CSS generation à\nla CSS Modules, with [`sketch_css`](https://hexdocs.pm/sketch_css/). As a user,\nyou want to grab one of those package, and start building! Both targets can be\nmixed too, to reach whoever you want! For framework authors, let&#39;s see you at\n[integration part](#integration)!\n\n## Installation\n\nSketch is published on [Hex](https://hex.pm/packages/sketch). Add it to your\nproject by using the gleam CLI.\n\n```bash\n# For Lustre integration\ngleam add sketch sketch_lustre\n# For CSS generation\ngleam add sketch sketch_css\n```\n\n## Core concept\n\nSketch focuses on the concept of generating CSS in a performant way. To do it,\nSketch needs to use a cache. The cache allows to avoid repeating unneeded\ncomputations, and ensure consistency across repaints. Because the browser likes\nstatic CSS, using a cache make sure the browser will not undergo unneeded\ncomputations to recompute styles at every repaint.\n\n## Sketch Lustre\n\n### Setup\n\nIf you&#39;re using Lustre (which is strongly recommended), `sketch_lustre` got you.\n`sketch_lustre` exposes one entrypoint, `sketch/lustre`, containing everything\nneeded to get started.\n\n```gleam\n// main.gleam\nimport lustre\nimport sketch\nimport sketch/lustre as sketch_lustre\n\npub fn main() {\n  // Initialise the cache. Two strategies can be used. Ephemeral caches are designed as throw-away caches.\n  let assert Ok(cache) = sketch.cache(strategy: sketch.Ephemeral)\n  // Select the output of the generated stylesheet.\n  sketch_lustre.node()\n  // Add the sketch CSS generation &quot;view middleware&quot;.\n  |&gt; sketch_lustre.compose(view, cache)\n  // Give the new view function to lustre runtime!\n  |&gt; lustre.simple(init, update, _)\n  // And voilà!\n  |&gt; lustre.start(&quot;#app&quot;, Nil)\n}\n```\n\n### Usage\n\n`sketch_lustre` exposes two modules to help you build your site, similarly to\nLustre: `sketch/lustre/element` and `sketch/lustre/element/html`. The first one\nlet you use raw element generation and exposes the Sketch Lustre `Element(msg)`\ntype, that can be used (almost) interchangeably with Lustre, and element\nhelpers, i.e. `element`, `fragment`, or even `keyed`.\n\nBecause a `sketch_lustre` view function expects an\n`sketch/lustre/element.Element(msg)` to paint, you should now write all your\nview functions to return Sketch elements. All Sketch elements can be\ninstanciated with `element`, or with the corresponding\n`sketch/lustre/element/html.element`. An element accepts the same thing as a\nLustre element, but includes a `sketch.Class` value as first argument. That\nclass will be applied to the final generated element.\n\nNB: all elements can be generated using the correct function, or using its\n&quot;underscored&quot; version. In the second case, Sketch Lustre behaves _exactly_ like\nLustre, and will not add another class. This is helpful when you want to use a\nsimple node, without any class linked on it.\n\n```gleam\nimport sketch\nimport sketch/lustre/element\nimport sketch/lustre/element/html\nimport sketch/size.{px}\n\nfn main_style() {\n  sketch.class([\n    sketch.background(&quot;red&quot;),\n    sketch.font_size(px(16)),\n  ])\n}\n\nfn view(model: Int) {\n  html.div(main_style(), [], [\n    html.div_([], [h.text(int.to_string(model))]),\n  ])\n}\n```\n\nAnd you&#39;re done! Enjoy your Lustre app, Sketch-enhanced!\n\n### Final notes\n\n#### On Sketch Lustre Element\n\nA Sketch `Element(msg)` is extremely similar to a Lustre `Element(msg)`,\nexcepted it carries styles information on top. Going from a\n`sketch/lustre/element.Element(msg)` to a `lustre/element.Element(msg)` is\nstraightforward, by using `sketch/lustre/element.unstyled`. The opposite (going\nfrom a Lustre element to a Sketch Lustre element) is also possible by using\n`sketch/lustre/element.styled`!\n\n#### Usage with Shadow DOM\n\nIn browser, Sketch can work with a Shadow DOM, in order to hide the compiled\nstyles from the rest of the application. To do it, you can use\n[`plinth`](https://github.com/CrowdHailer/plinth). This allows to create a\n`ShadowRoot`, to use\n[`sketch/options.shadow_root()`](https://hexdocs.pm/sketch/sketch/options.html#shadow_root).\nIn the same way you can initialize the cache to render in document or in a\n`style` node, you can now use a Shadow Root to paint styles in your application!\n\n## Sketch Redraw\n\n### Setup\n\nWhen you&#39;re using Redraw, `sketch_redraw` covers you. `sketch_redraw` exposes\none entrypoint, `sketch/redraw`, containing everything needed to get started.\n\n```gleam\n// main.gleam\nimport redraw\nimport sketch\nimport sketch/redraw as sketch_redraw\n\npub fn main() {\n  let root = client.create_root(&quot;root&quot;)\n  client.render(root, redraw.strict_mode([\n    // Initialise the cache. Sketch Redraw handles the details for you.\n    sr.provider([\n      // Here comes your components!\n    ])\n  ]))\n}\n```\n\n### Usage\n\n`sketch_redraw` exposes one module to help you build your site, similarly to\nredraw: `sketch/redraw/html`. `html` is simply a supercharged component,\naccepting a `sketch.Class` as first argument, and applies that style to the\nnode. Because it&#39;s a simple component, `sketch/redraw/html` and `redraw/html`\ncan be mixed in the same code without issue! Because of that property,\n`sketch_redraw` _does not_ expose `text` and `none` function at that time.\n\n```gleam\nimport redraw/html as h\nimport sketch\nimport sketch/redraw/html\nimport sketch/size.{px}\n\nfn main_style() {\n  sketch.class([\n    sketch.background(&quot;red&quot;),\n    sketch.font_size(px(16)),\n  ])\n}\n\nfn view(model: Int) {\n  html.div(main_style(), [], [\n    h.div([], [\n      h.text(int.to_string(model))\n    ]),\n  ])\n}\n```\n\nAnd you&#39;re done! Enjoy your Redraw app, Sketch-enhanced!\n\n### Final notes\n\nSketch Redraw tries to integrate nicely with React Devtools! In case you&#39;re\nseeing something weird, signal the bug!\n\n## Sketch CSS\n\nBecause pure CSS generation is straightforward, `sketch_css` does not need a\ncache to generate correct CSS files. Instead, `sketch_css` ships with a CLI\ntool, able to read your Gleam styles files, and output corresponding your CSS\nautomagically, while providing an abstraction layer written in Gleam, to make\nsure you&#39;re using the right classes! It&#39;s an other way to leverage on Sketch\ncore and enjoy the styling in Gleam, while taking advantage of all the static\nCSS power!\n\nTo run the generator, you have to use the command\n`gleam run -m sketch/css generate` at the root of your project. By default,\n`sketch_css` will try to read all files named `*_styles.gleam`, `*_css.gleam`\nand `*_sketch.gleam` in your `src` folder, no matter where they are. You can put\nthem at root, nested, or in a folder called `css`, `sketch_css` does not care!\nAfter fetching the styles files, `sketch_css` will output your generated CSS\nfiles in a `styles` folder, at the root of the project. They can then be served\nin the way you want. In the same time, `sketch_css` will output Gleam interfaces\nin `src/sketch/styles`, matching your styles files, to use in your project!\n\n### Options\n\nSketch CSS generation has strong defaults, but everything can be customised. Use\nthe CLI flags to configure what you need. CLI exposes 3 flags:\n\n- `--dest`, accepting a folder, relative to current directory. It defaults to\n  `styles`\n- `--src`, accepting a folder, relative to current directory. It defaults to\n  `src`.\n- `--interface`, accepting a folder, relative to current directory. It defaults\n  to `src/sketch/styles`.\n\n### A note on generation algorithm\n\nBecause a Sketch `Class` can be generated in multiple ways, and with variable,\nSketch CSS takes that into account. Every simple Sketch `Class` will be iso\ngenerated in CSS, but every Sketch `Class` that contains variable will be\ngenerated with the variable taken into account! Sketch CSS being opinionated, it\ngenerates the class, with a CSS variable, letting you update it, override it,\netc.\n\nAll `_` are also automatically transformed into `-`, because CSS classes are\nmost of the time used with dashes, so Sketch CSS follows that convention!\n\n### Example\n\n```gleam\n// src/main_styles.gleam\nimport sketch\n\nfn flexer() {\n  sketch.class([\n    sketch.display(&quot;flex&quot;),\n  ])\n}\n\nfn flexer_direction(flex_direction: String) {\n  sketch.class([\n    sketch.compose(flexer()),\n    sketch.flex_direction(flex_direction),\n  ])\n}\n```\n\n```css\n/* styles/main_styles.css */\n.flexer {\n  display: flex;\n}\n\n.flexer-direction {\n  flex-direction: var(--flex-direction);\n}\n```\n\n```gleam\n// src/sketch/styles/main_styles.gleam\npub const flexer = &quot;flexer&quot;\n\npub const flexer_direction = &quot;flexer flexer-direction&quot;\n```\n\n## Sketch general usage\n\nAt its core, Sketch relies on `sketch.class`, which let you define a class. A\nclass is made of CSS properties. All of those can be accessed in `sketch`\nmodule. Build your classes, and use them across your codebase!\n\n## Using media queries and pseudo-selectors\n\nBecause we&#39;re building CSS, we can leverage on its full power, contrarily to\ninline styling. This mean we can use media queries and pseudo-selectors! You\nonly need to call the proper functions, and Sketch will take care of the rest.\n\n```gleam\nimport sketch\nimport sketch/media\nimport sketch/size.{px}\n\nfn my_class() {\n  sketch.class([\n    sketch.display(&quot;flex&quot;),\n    sketch.flex_direction(&quot;row&quot;),\n    sketch.background(&quot;red&quot;),\n    sketch.hover([\n      sketch.background(&quot;blue&quot;),\n    ]),\n    sketch.media(media.max_width(px(320)), [\n      sketch.flex_direction(&quot;column&quot;),\n      sketch.hover([\n        sketch.background(&quot;green&quot;),\n      ]),\n    ]),\n  ])\n}\n```\n\nThe example above will be compiled to the following CSS.\n\n```css\n.my-class {\n  display: flex;\n  flex-direction: row;\n  background: red;\n}\n\n.my-class:hover {\n  background: blue;\n}\n\n@media (max-width: 320px) {\n  .my-class {\n    flex-direction: column;\n  }\n\n  .my-class:hover {\n    background: green;\n  }\n}\n```\n\n## Composition\n\nBecause we oftentimes need to compose CSS classes, Sketch provides a `compose`\nfunction, acting like CSS Modules `compose` property. This allow you to reuse\nCSS properties from another class, without having the burden of copy-pasting the\nstyles, or having to think on the class names to put in your nodes! Of course,\nthis remains totally optional. An example:\n\n```gleam\nfn button_style() {\n  sketch.class([\n    sketch.appearance(&quot;none&quot;),\n    sketch.border(&quot;none&quot;),\n    sketch.border_radius(px(10)),\n    sketch.transition(&quot;all .2s&quot;),\n  ])\n}\n\nfn enabled_button_style() {\n  sketch.class([\n    sketch.compose(button_style()),\n    sketch.background(&quot;red&quot;),\n    sketch.color(&quot;white&quot;),\n  ])\n}\n\nfn disabled_button_style() {\n  sketch.class([\n    sketch.compose(button_style()),\n    sketch.background(&quot;grey&quot;),\n    sketch.color(&quot;black&quot;),\n  ])\n}\n\nfn button(disabled) {\n  let class = case disabled {\n    True -&gt; disabled_button_style()\n    False -&gt; enabled_button_style()\n  }\n  html.button(class, [], [html.text(&quot;Yay!&quot;)])\n}\n```\n\n## Some opinions on properties\n\nA lot of properties are accessible directly through the `sketch` package. But\nwith time, some could be added, and new features for existing properties can\nappear. That&#39;s why Sketch will never try to be on your way: at any time you can\naccess [`property()`](https://hexdocs.pm/sketch/sketch.html#property), which\nallows you to push any arbitrary property in a class. Another thing is that\nSketch will always let you access raw, low-level properties. If you&#39;re trying to\nuse something like `sketch.width(&quot;auto&quot;)` and the property does not support\nString, look for a variant with an underscore (`_`), it should fullfill your\nneeds, like `sketch.width_(&quot;auto&quot;)`! In case something is missing or a property\ndoes not have its underscore alternative,\n[open an issue — or better, a PR — on the repo!](https://github.com/ghivert/sketch)\n\n## Integration\n\n&gt; This part is new, and subject to modification. Because nobody integrated\n&gt; Sketch in their framework yet, it&#39;s hard to write a correct guide, that is\n&gt; useful and not redundant. If you&#39;re in the case of writing a framework\n&gt; binding, please, let&#39;s keep in touch directly, and I&#39;ll help you integrate\n&gt; Sketch. That would be immensely helpful, to write a correct guide after this!\n&gt; Meanwhile, you can find necessary pointers below to help you get started by\n&gt; yourself!\n\nIf you&#39;re here, it means you&#39;re interested in integrating Sketch in your\nframework! What a wonderful idea!\n\nTo integrate Sketch in your framework, you have 2 choices:\n\n- run Sketch in your repaint function.\n- compiles all Sketch files as static code.\n\nTo run Sketch in your repaint function, your only need is to run\n`sketch.class_name` on a `sketch.Class`. Let your users write `sketch.Class`,\nand then, do the hard work of wiring everything up by calling\n`sketch.class_name`. This requires a `sketch.Cache` to run correctly. Take a\nlook at what is happening in `sketch_lustre` to figure out how everything works.\n\nA nice way is also to precompile everything, like `sketch_css` is doing. Instead\nof generating the CSS on-the-fly, which browsers does not really like, you can\nprecompute everything. By using a Gleam parser, like `glance`, you could compile\neverything to plain CSS. This area is subject of exploration, and is the way\n`sketch_lustre` tries to follow in some specific environments, like Vite and\nLustre Dev tools. If you&#39;re interested in the subject, let&#39;s keep in touch!\n","url":"index.html"},{"doc":"sketch","title":"sketch","content":"","url":"#"},{"doc":"sketch","title":"sketch","content":"# Usage with BEAM\n\nSketch can be transparently used with BEAM and JS, however, due to the runtime,\nsome differences exists, and should be taken in consideration. Contrarily to JS,\nBEAM is a runtime which is actor oriented, and synchronous.\n\nTo generate the real stylesheet the application will use, sketch uses an\nintermediate virtual stylesheet, called &quot;cache&quot;. In BEAM, a cache is a process,\nstoring its own state.\n\nJust like with any app, creating a cache relies on\n[`cache`](https://hexdocs.pm/sketch/sketch.html#cache). Once created, a cache\nwill live as long as you not destroy it. To access the generated stylesheet,\n[`render`](https://hexdocs.pm/sketch/sketch.html#render) will turn the cache\ninto a proper stylesheet, i.e. it will returns a `String`, containing the\nstylesheet content. All you have to do then is to embed the resulting string in\nyour output HTML, and voilà!\n\n## Example\n\nThe example assumes you&#39;re using a blank, empty\n[`mist`](https://hexdocs.pm/mist) server. It could feel a little cumbersome, but\nmost of the time, your framework should handle it directly.\n\n```gleam\nimport gleam/bytes_builder\nimport gleam/erlang/process\nimport gleam/http/request.{type Request}\nimport gleam/http/response.{type Response}\nimport gleam/string\nimport mist.{type Connection, type ResponseData}\nimport sketch\nimport sketch/options as sketch_options\n\npub fn main() {\n  // Creates the cache here. A global cache will be used here, because the SSR\n  // only uses one process.\n  let assert Ok(cache) = sketch.cache(strategy: sketch.Persistent)\n\n  // Helpers for mist server.\n  let empty_body = mist.Bytes(bytes_builder.new())\n  let not_found = response.set_body(response.new(404), empty_body)\n\n  let assert Ok(_) =\n    fn(req: Request(Connection)) -&gt; Response(ResponseData) {\n      // Before every request, prepare the cache, to wipe it from old data, and\n      // mark it as &quot;default&quot; cache for the following render.\n      case request.path_segments(req) {\n        // Send the cache to your render function. It will be used before\n        // returning the HTML.\n        [&quot;greet&quot;, name] -&gt; greet(name, cache)\n        _ -&gt; not_found\n      }\n    }\n    |&gt; mist.new()\n    |&gt; mist.port(3000)\n    |&gt; mist.start_http()\n\n  process.sleep_forever()\n}\n\n// Defines a class, here with simple class name.\nfn main_class(cache) {\n  [sketch.color(&quot;red&quot;)]\n  |&gt; sketch.class()\n  |&gt; sketch.to_class_name(cache)\n}\n\nfn greet(name: String, cache: sketch.Cache) -&gt; Response(ResponseData) {\n  let res = response.new(200)\n  let greetings = &quot;&lt;div&gt;Hey there, &quot; &lt;&gt; name &lt;&gt; &quot;!&lt;/div&gt;&quot;\n\n  // Create your body, with the classes computed.\n  let #(class_name, cache) = main_class(cache)\n  let body =\n    [\n      &quot;&lt;div class=&quot; &lt;&gt; class_name &lt;&gt; &quot;&gt;&quot;,\n      &quot;  &lt;div&gt;Hello World!&lt;/div&gt;&quot;,\n      greetings,\n      &quot;&lt;/div&gt;&quot;,\n    ]\n    |&gt; string.join(&quot;\\n&quot;)\n\n  // Get the content of your stylesheet.\n  let assert Ok(stylesheet_content) = sketch.render(cache)\n\n  // Render the style in your HTML.\n  let html =\n    [\n      &quot;&lt;html&gt;&quot;,\n      &quot;  &lt;head&gt;&quot;,\n      &quot;    &lt;style&gt;&quot;,\n      stylesheet_content,\n      &quot;    &lt;/style&gt;&quot;,\n      &quot;  &lt;/head&gt;&quot;,\n      &quot;  &lt;body&gt;&quot;,\n      body,\n      &quot;  &lt;/body&gt;&quot;,\n      &quot;&lt;/html&gt;&quot;,\n    ]\n    |&gt; string.join(&quot;\\n&quot;)\n\n  html\n  |&gt; bytes_builder.from_string()\n  |&gt; mist.Bytes()\n  |&gt; response.set_body(res, _)\n}\n```\n\n## More details\n\nYou can find more details on how it works in the\n[internal details](https://hexdocs.pm/sketch/internal-details.html).\n","url":"usage-with-beam.html"},{"doc":"sketch/size","title":"Size","content":"pub opaque type Size\n Size defines a CSS Unit. It can be either `px`, `pt`, `vh`, `vw`, `em`,\n `rem`, `lh`, `rlh`, `ch`, `%`. To instanciate a Size, use the corresponding\n functions. Every unit exposes two functions: the Int function (like `px(0)`)\n and the Float version suffixed by an underscore (like `px_(0.0)`).\n\nSynonyms:\nsketch/size.Size\nsketch/size Size","url":"sketch/size.html#Size"},{"doc":"sketch/size","title":"ch","content":"pub fn ch(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.ch\nsketch/size ch","url":"sketch/size.html#ch"},{"doc":"sketch/size","title":"ch_","content":"pub fn ch_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.ch_\nsketch/size ch_","url":"sketch/size.html#ch_"},{"doc":"sketch/size","title":"em","content":"pub fn em(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.em\nsketch/size em","url":"sketch/size.html#em"},{"doc":"sketch/size","title":"lh","content":"pub fn lh(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.lh\nsketch/size lh","url":"sketch/size.html#lh"},{"doc":"sketch/size","title":"percent","content":"pub fn percent(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.percent\nsketch/size percent","url":"sketch/size.html#percent"},{"doc":"sketch/size","title":"percent_","content":"pub fn percent_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.percent_\nsketch/size percent_","url":"sketch/size.html#percent_"},{"doc":"sketch/size","title":"pt","content":"pub fn pt(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.pt\nsketch/size pt","url":"sketch/size.html#pt"},{"doc":"sketch/size","title":"pt_","content":"pub fn pt_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.pt_\nsketch/size pt_","url":"sketch/size.html#pt_"},{"doc":"sketch/size","title":"px","content":"pub fn px(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.px\nsketch/size px","url":"sketch/size.html#px"},{"doc":"sketch/size","title":"px_","content":"pub fn px_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.px_\nsketch/size px_","url":"sketch/size.html#px_"},{"doc":"sketch/size","title":"rem","content":"pub fn rem(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.rem\nsketch/size rem","url":"sketch/size.html#rem"},{"doc":"sketch/size","title":"rlh","content":"pub fn rlh(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.rlh\nsketch/size rlh","url":"sketch/size.html#rlh"},{"doc":"sketch/size","title":"to_string","content":"pub fn to_string(size: Size) -&gt; String\n Internal function, can be used if you need to go from a Size to a String\n in case you&#39;re building on top of sketch.\nSynonyms:\nsketch/size.to_string\nsketch/size to_string","url":"sketch/size.html#to_string"},{"doc":"sketch/size","title":"vh","content":"pub fn vh(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.vh\nsketch/size vh","url":"sketch/size.html#vh"},{"doc":"sketch/size","title":"vh_","content":"pub fn vh_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.vh_\nsketch/size vh_","url":"sketch/size.html#vh_"},{"doc":"sketch/size","title":"vw","content":"pub fn vw(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.vw\nsketch/size vw","url":"sketch/size.html#vw"},{"doc":"sketch/size","title":"vw_","content":"pub fn vw_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.vw_\nsketch/size vw_","url":"sketch/size.html#vw_"},{"doc":"sketch/size","title":"sketch/size","content":" Defines sizes directly with functions, to avoid conversions between int, float\n and strings.","url":"sketch/size.html"},{"doc":"sketch/media","title":"ColorMode","content":"pub opaque type ColorMode\n\n\nSynonyms:\nsketch/media.ColorMode\nsketch/media ColorMode","url":"sketch/media.html#ColorMode"},{"doc":"sketch/media","title":"Query","content":"pub opaque type Query\n\n\nSynonyms:\nsketch/media.Query\nsketch/media Query","url":"sketch/media.html#Query"},{"doc":"sketch/media","title":"and","content":"pub fn and(first: Query, second: Query) -&gt; Query\n\nSynonyms:\nsketch/media.and\nsketch/media and","url":"sketch/media.html#and"},{"doc":"sketch/media","title":"dark_theme","content":"pub fn dark_theme() -&gt; Query\n\nSynonyms:\nsketch/media.dark_theme\nsketch/media dark_theme","url":"sketch/media.html#dark_theme"},{"doc":"sketch/media","title":"landscape","content":"pub fn landscape() -&gt; Query\n\nSynonyms:\nsketch/media.landscape\nsketch/media landscape","url":"sketch/media.html#landscape"},{"doc":"sketch/media","title":"light_theme","content":"pub fn light_theme() -&gt; Query\n\nSynonyms:\nsketch/media.light_theme\nsketch/media light_theme","url":"sketch/media.html#light_theme"},{"doc":"sketch/media","title":"max_height","content":"pub fn max_height(size: Size) -&gt; Query\n\nSynonyms:\nsketch/media.max_height\nsketch/media max_height","url":"sketch/media.html#max_height"},{"doc":"sketch/media","title":"max_width","content":"pub fn max_width(size: Size) -&gt; Query\n\nSynonyms:\nsketch/media.max_width\nsketch/media max_width","url":"sketch/media.html#max_width"},{"doc":"sketch/media","title":"min_height","content":"pub fn min_height(size: Size) -&gt; Query\n\nSynonyms:\nsketch/media.min_height\nsketch/media min_height","url":"sketch/media.html#min_height"},{"doc":"sketch/media","title":"min_width","content":"pub fn min_width(size: Size) -&gt; Query\n\nSynonyms:\nsketch/media.min_width\nsketch/media min_width","url":"sketch/media.html#min_width"},{"doc":"sketch/media","title":"not","content":"pub fn not(query: Query) -&gt; Query\n\nSynonyms:\nsketch/media.not\nsketch/media not","url":"sketch/media.html#not"},{"doc":"sketch/media","title":"or","content":"pub fn or(first: Query, second: Query) -&gt; Query\n\nSynonyms:\nsketch/media.or\nsketch/media or","url":"sketch/media.html#or"},{"doc":"sketch/media","title":"portrait","content":"pub fn portrait() -&gt; Query\n\nSynonyms:\nsketch/media.portrait\nsketch/media portrait","url":"sketch/media.html#portrait"},{"doc":"sketch/media","title":"to_string","content":"pub fn to_string(query: Query) -&gt; String\n Internal function, can be used if you need to go from a media query to a String\n in case you&#39;re building on top of sketch.\nSynonyms:\nsketch/media.to_string\nsketch/media to_string","url":"sketch/media.html#to_string"},{"doc":"sketch/media","title":"sketch/media","content":" Define media queries directly with functions.\n Refer to the sketch module to get more details on the usage.\n\n ## Advanced usage\n\n Media queries can be rather complex, and the module tries to give all\n features in a usable way. A media query takes form (property: value) and\n can be combined, like (orientation: landscape) or (min-width: 1000px).\n Those media queries can be created by using the corresponding `and`,\n `or` or `not` functions.","url":"sketch/media.html"},{"doc":"sketch","title":"Cache","content":"pub opaque type Cache\n Manages the styles. Can be instanciated with [`cache`](#cache).\n\nSynonyms:\nsketch.Cache\nsketch Cache","url":"sketch.html#Cache"},{"doc":"sketch","title":"Class","content":"pub type Class =\n  style.Class\n Represents a CSS class, compiled.\n\nSynonyms:\nsketch.Class\nsketch Class","url":"sketch.html#Class"},{"doc":"sketch","title":"Strategy","content":"pub type Strategy {\n  Ephemeral\n  Persistent\n}\n Strategy for the Cache. Two strategies are available as of now: ephemeral\n and persistent. In the first case, the cache is throwable, and every class\n generation wil rely on hashing function. It means two class names will be\n identical if their content are identical.\n In the second case, the cache is persistent, meaning it will keep the\n memories of the generated classes.\nEphemeral\n\n\nPersistent\n\n\nSynonyms:\nsketch.Strategy\nsketch Strategy","url":"sketch.html#Strategy"},{"doc":"sketch","title":"Style","content":"pub type Style =\n  style.Style\n Represents a Style. It can be a class composition, a media query with its\n sub-properties, a pseudo-selector with its sub-properties or a property\n directly.\n\nSynonyms:\nsketch.Style\nsketch Style","url":"sketch.html#Style"},{"doc":"sketch","title":"accent_color","content":"pub fn accent_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.accent_color\nsketch accent_color","url":"sketch.html#accent_color"},{"doc":"sketch","title":"active","content":"pub fn active(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.active\nsketch active","url":"sketch.html#active"},{"doc":"sketch","title":"align_content","content":"pub fn align_content(align: String) -&gt; Style\n\nSynonyms:\nsketch.align_content\nsketch align_content","url":"sketch.html#align_content"},{"doc":"sketch","title":"align_items","content":"pub fn align_items(align: String) -&gt; Style\n\nSynonyms:\nsketch.align_items\nsketch align_items","url":"sketch.html#align_items"},{"doc":"sketch","title":"align_self","content":"pub fn align_self(align: String) -&gt; Style\n\nSynonyms:\nsketch.align_self\nsketch align_self","url":"sketch.html#align_self"},{"doc":"sketch","title":"align_tracks","content":"pub fn align_tracks(align: String) -&gt; Style\n\nSynonyms:\nsketch.align_tracks\nsketch align_tracks","url":"sketch.html#align_tracks"},{"doc":"sketch","title":"all","content":"pub fn all(value: String) -&gt; Style\n\nSynonyms:\nsketch.all\nsketch all","url":"sketch.html#all"},{"doc":"sketch","title":"animation","content":"pub fn animation(animation: String) -&gt; Style\n\nSynonyms:\nsketch.animation\nsketch animation","url":"sketch.html#animation"},{"doc":"sketch","title":"animation_composition","content":"pub fn animation_composition(animation: String) -&gt; Style\n\nSynonyms:\nsketch.animation_composition\nsketch animation_composition","url":"sketch.html#animation_composition"},{"doc":"sketch","title":"animation_delay","content":"pub fn animation_delay(animation: String) -&gt; Style\n\nSynonyms:\nsketch.animation_delay\nsketch animation_delay","url":"sketch.html#animation_delay"},{"doc":"sketch","title":"animation_direction","content":"pub fn animation_direction(animation: String) -&gt; Style\n\nSynonyms:\nsketch.animation_direction\nsketch animation_direction","url":"sketch.html#animation_direction"},{"doc":"sketch","title":"animation_duration","content":"pub fn animation_duration(animation: String) -&gt; Style\n\nSynonyms:\nsketch.animation_duration\nsketch animation_duration","url":"sketch.html#animation_duration"},{"doc":"sketch","title":"animation_fill_mode","content":"pub fn animation_fill_mode(animation: String) -&gt; Style\n\nSynonyms:\nsketch.animation_fill_mode\nsketch animation_fill_mode","url":"sketch.html#animation_fill_mode"},{"doc":"sketch","title":"animation_iteration_count","content":"pub fn animation_iteration_count(animation: String) -&gt; Style\n\nSynonyms:\nsketch.animation_iteration_count\nsketch animation_iteration_count","url":"sketch.html#animation_iteration_count"},{"doc":"sketch","title":"animation_name","content":"pub fn animation_name(animation: String) -&gt; Style\n\nSynonyms:\nsketch.animation_name\nsketch animation_name","url":"sketch.html#animation_name"},{"doc":"sketch","title":"animation_play_state","content":"pub fn animation_play_state(animation: String) -&gt; Style\n\nSynonyms:\nsketch.animation_play_state\nsketch animation_play_state","url":"sketch.html#animation_play_state"},{"doc":"sketch","title":"animation_timing_function","content":"pub fn animation_timing_function(animation: String) -&gt; Style\n\nSynonyms:\nsketch.animation_timing_function\nsketch animation_timing_function","url":"sketch.html#animation_timing_function"},{"doc":"sketch","title":"appearance","content":"pub fn appearance(appearance: String) -&gt; Style\n\nSynonyms:\nsketch.appearance\nsketch appearance","url":"sketch.html#appearance"},{"doc":"sketch","title":"aspect_ratio","content":"pub fn aspect_ratio(aspect_ratio: String) -&gt; Style\n\nSynonyms:\nsketch.aspect_ratio\nsketch aspect_ratio","url":"sketch.html#aspect_ratio"},{"doc":"sketch","title":"backdrop_filter","content":"pub fn backdrop_filter(value: String) -&gt; Style\n\nSynonyms:\nsketch.backdrop_filter\nsketch backdrop_filter","url":"sketch.html#backdrop_filter"},{"doc":"sketch","title":"backface_visibility","content":"pub fn backface_visibility(value: String) -&gt; Style\n\nSynonyms:\nsketch.backface_visibility\nsketch backface_visibility","url":"sketch.html#backface_visibility"},{"doc":"sketch","title":"background","content":"pub fn background(background: String) -&gt; Style\n\nSynonyms:\nsketch.background\nsketch background","url":"sketch.html#background"},{"doc":"sketch","title":"background_attachment","content":"pub fn background_attachment(value: String) -&gt; Style\n\nSynonyms:\nsketch.background_attachment\nsketch background_attachment","url":"sketch.html#background_attachment"},{"doc":"sketch","title":"background_blend_mode","content":"pub fn background_blend_mode(value: String) -&gt; Style\n\nSynonyms:\nsketch.background_blend_mode\nsketch background_blend_mode","url":"sketch.html#background_blend_mode"},{"doc":"sketch","title":"background_clip","content":"pub fn background_clip(value: String) -&gt; Style\n\nSynonyms:\nsketch.background_clip\nsketch background_clip","url":"sketch.html#background_clip"},{"doc":"sketch","title":"background_color","content":"pub fn background_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.background_color\nsketch background_color","url":"sketch.html#background_color"},{"doc":"sketch","title":"background_image","content":"pub fn background_image(value: String) -&gt; Style\n\nSynonyms:\nsketch.background_image\nsketch background_image","url":"sketch.html#background_image"},{"doc":"sketch","title":"background_origin","content":"pub fn background_origin(value: String) -&gt; Style\n\nSynonyms:\nsketch.background_origin\nsketch background_origin","url":"sketch.html#background_origin"},{"doc":"sketch","title":"background_position","content":"pub fn background_position(value: String) -&gt; Style\n\nSynonyms:\nsketch.background_position\nsketch background_position","url":"sketch.html#background_position"},{"doc":"sketch","title":"background_position_x","content":"pub fn background_position_x(value: String) -&gt; Style\n\nSynonyms:\nsketch.background_position_x\nsketch background_position_x","url":"sketch.html#background_position_x"},{"doc":"sketch","title":"background_position_y","content":"pub fn background_position_y(value: String) -&gt; Style\n\nSynonyms:\nsketch.background_position_y\nsketch background_position_y","url":"sketch.html#background_position_y"},{"doc":"sketch","title":"background_repeat","content":"pub fn background_repeat(value: String) -&gt; Style\n\nSynonyms:\nsketch.background_repeat\nsketch background_repeat","url":"sketch.html#background_repeat"},{"doc":"sketch","title":"background_size","content":"pub fn background_size(background: String) -&gt; Style\n\nSynonyms:\nsketch.background_size\nsketch background_size","url":"sketch.html#background_size"},{"doc":"sketch","title":"blank","content":"pub fn blank(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.blank\nsketch blank","url":"sketch.html#blank"},{"doc":"sketch","title":"block_size","content":"pub fn block_size(value: Size) -&gt; Style\n\nSynonyms:\nsketch.block_size\nsketch block_size","url":"sketch.html#block_size"},{"doc":"sketch","title":"block_size_","content":"pub fn block_size_(value: String) -&gt; Style\n\nSynonyms:\nsketch.block_size_\nsketch block_size_","url":"sketch.html#block_size_"},{"doc":"sketch","title":"border","content":"pub fn border(border: String) -&gt; Style\n\nSynonyms:\nsketch.border\nsketch border","url":"sketch.html#border"},{"doc":"sketch","title":"border_block","content":"pub fn border_block(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block\nsketch border_block","url":"sketch.html#border_block"},{"doc":"sketch","title":"border_block_color","content":"pub fn border_block_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_color\nsketch border_block_color","url":"sketch.html#border_block_color"},{"doc":"sketch","title":"border_block_end","content":"pub fn border_block_end(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_end\nsketch border_block_end","url":"sketch.html#border_block_end"},{"doc":"sketch","title":"border_block_end_color","content":"pub fn border_block_end_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_end_color\nsketch border_block_end_color","url":"sketch.html#border_block_end_color"},{"doc":"sketch","title":"border_block_end_style","content":"pub fn border_block_end_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_end_style\nsketch border_block_end_style","url":"sketch.html#border_block_end_style"},{"doc":"sketch","title":"border_block_end_width","content":"pub fn border_block_end_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_block_end_width\nsketch border_block_end_width","url":"sketch.html#border_block_end_width"},{"doc":"sketch","title":"border_block_end_width_","content":"pub fn border_block_end_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_end_width_\nsketch border_block_end_width_","url":"sketch.html#border_block_end_width_"},{"doc":"sketch","title":"border_block_start","content":"pub fn border_block_start(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_start\nsketch border_block_start","url":"sketch.html#border_block_start"},{"doc":"sketch","title":"border_block_start_color","content":"pub fn border_block_start_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_start_color\nsketch border_block_start_color","url":"sketch.html#border_block_start_color"},{"doc":"sketch","title":"border_block_start_style","content":"pub fn border_block_start_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_start_style\nsketch border_block_start_style","url":"sketch.html#border_block_start_style"},{"doc":"sketch","title":"border_block_start_width","content":"pub fn border_block_start_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_block_start_width\nsketch border_block_start_width","url":"sketch.html#border_block_start_width"},{"doc":"sketch","title":"border_block_start_width_","content":"pub fn border_block_start_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_start_width_\nsketch border_block_start_width_","url":"sketch.html#border_block_start_width_"},{"doc":"sketch","title":"border_block_style","content":"pub fn border_block_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_style\nsketch border_block_style","url":"sketch.html#border_block_style"},{"doc":"sketch","title":"border_block_width","content":"pub fn border_block_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_block_width\nsketch border_block_width","url":"sketch.html#border_block_width"},{"doc":"sketch","title":"border_block_width_","content":"pub fn border_block_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_block_width_\nsketch border_block_width_","url":"sketch.html#border_block_width_"},{"doc":"sketch","title":"border_bottom","content":"pub fn border_bottom(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_bottom\nsketch border_bottom","url":"sketch.html#border_bottom"},{"doc":"sketch","title":"border_bottom_color","content":"pub fn border_bottom_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_bottom_color\nsketch border_bottom_color","url":"sketch.html#border_bottom_color"},{"doc":"sketch","title":"border_bottom_left_radius","content":"pub fn border_bottom_left_radius(\n  border_bottom_left_radius: Size,\n) -&gt; Style\n\nSynonyms:\nsketch.border_bottom_left_radius\nsketch border_bottom_left_radius","url":"sketch.html#border_bottom_left_radius"},{"doc":"sketch","title":"border_bottom_left_radius_","content":"pub fn border_bottom_left_radius_(\n  border_bottom_left_radius: String,\n) -&gt; Style\n\nSynonyms:\nsketch.border_bottom_left_radius_\nsketch border_bottom_left_radius_","url":"sketch.html#border_bottom_left_radius_"},{"doc":"sketch","title":"border_bottom_right_radius","content":"pub fn border_bottom_right_radius(\n  border_bottom_right_radius: Size,\n) -&gt; Style\n\nSynonyms:\nsketch.border_bottom_right_radius\nsketch border_bottom_right_radius","url":"sketch.html#border_bottom_right_radius"},{"doc":"sketch","title":"border_bottom_right_radius_","content":"pub fn border_bottom_right_radius_(\n  border_bottom_right_radius: String,\n) -&gt; Style\n\nSynonyms:\nsketch.border_bottom_right_radius_\nsketch border_bottom_right_radius_","url":"sketch.html#border_bottom_right_radius_"},{"doc":"sketch","title":"border_bottom_style","content":"pub fn border_bottom_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_bottom_style\nsketch border_bottom_style","url":"sketch.html#border_bottom_style"},{"doc":"sketch","title":"border_bottom_width","content":"pub fn border_bottom_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_bottom_width\nsketch border_bottom_width","url":"sketch.html#border_bottom_width"},{"doc":"sketch","title":"border_bottom_width_","content":"pub fn border_bottom_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_bottom_width_\nsketch border_bottom_width_","url":"sketch.html#border_bottom_width_"},{"doc":"sketch","title":"border_collapse","content":"pub fn border_collapse(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_collapse\nsketch border_collapse","url":"sketch.html#border_collapse"},{"doc":"sketch","title":"border_color","content":"pub fn border_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_color\nsketch border_color","url":"sketch.html#border_color"},{"doc":"sketch","title":"border_end_end_radius","content":"pub fn border_end_end_radius(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_end_end_radius\nsketch border_end_end_radius","url":"sketch.html#border_end_end_radius"},{"doc":"sketch","title":"border_end_start_radius","content":"pub fn border_end_start_radius(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_end_start_radius\nsketch border_end_start_radius","url":"sketch.html#border_end_start_radius"},{"doc":"sketch","title":"border_image","content":"pub fn border_image(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_image\nsketch border_image","url":"sketch.html#border_image"},{"doc":"sketch","title":"border_image_outset","content":"pub fn border_image_outset(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_image_outset\nsketch border_image_outset","url":"sketch.html#border_image_outset"},{"doc":"sketch","title":"border_image_outset_","content":"pub fn border_image_outset_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_image_outset_\nsketch border_image_outset_","url":"sketch.html#border_image_outset_"},{"doc":"sketch","title":"border_image_repeat","content":"pub fn border_image_repeat(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_image_repeat\nsketch border_image_repeat","url":"sketch.html#border_image_repeat"},{"doc":"sketch","title":"border_image_slice","content":"pub fn border_image_slice(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_image_slice\nsketch border_image_slice","url":"sketch.html#border_image_slice"},{"doc":"sketch","title":"border_image_source","content":"pub fn border_image_source(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_image_source\nsketch border_image_source","url":"sketch.html#border_image_source"},{"doc":"sketch","title":"border_image_width","content":"pub fn border_image_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_image_width\nsketch border_image_width","url":"sketch.html#border_image_width"},{"doc":"sketch","title":"border_image_width_","content":"pub fn border_image_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_image_width_\nsketch border_image_width_","url":"sketch.html#border_image_width_"},{"doc":"sketch","title":"border_inline","content":"pub fn border_inline(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline\nsketch border_inline","url":"sketch.html#border_inline"},{"doc":"sketch","title":"border_inline_color","content":"pub fn border_inline_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_color\nsketch border_inline_color","url":"sketch.html#border_inline_color"},{"doc":"sketch","title":"border_inline_end","content":"pub fn border_inline_end(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_end\nsketch border_inline_end","url":"sketch.html#border_inline_end"},{"doc":"sketch","title":"border_inline_end_color","content":"pub fn border_inline_end_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_end_color\nsketch border_inline_end_color","url":"sketch.html#border_inline_end_color"},{"doc":"sketch","title":"border_inline_end_style","content":"pub fn border_inline_end_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_end_style\nsketch border_inline_end_style","url":"sketch.html#border_inline_end_style"},{"doc":"sketch","title":"border_inline_end_width","content":"pub fn border_inline_end_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_inline_end_width\nsketch border_inline_end_width","url":"sketch.html#border_inline_end_width"},{"doc":"sketch","title":"border_inline_end_width_","content":"pub fn border_inline_end_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_end_width_\nsketch border_inline_end_width_","url":"sketch.html#border_inline_end_width_"},{"doc":"sketch","title":"border_inline_start","content":"pub fn border_inline_start(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_start\nsketch border_inline_start","url":"sketch.html#border_inline_start"},{"doc":"sketch","title":"border_inline_start_color","content":"pub fn border_inline_start_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_start_color\nsketch border_inline_start_color","url":"sketch.html#border_inline_start_color"},{"doc":"sketch","title":"border_inline_start_style","content":"pub fn border_inline_start_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_start_style\nsketch border_inline_start_style","url":"sketch.html#border_inline_start_style"},{"doc":"sketch","title":"border_inline_start_width","content":"pub fn border_inline_start_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_inline_start_width\nsketch border_inline_start_width","url":"sketch.html#border_inline_start_width"},{"doc":"sketch","title":"border_inline_start_width_","content":"pub fn border_inline_start_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_start_width_\nsketch border_inline_start_width_","url":"sketch.html#border_inline_start_width_"},{"doc":"sketch","title":"border_inline_style","content":"pub fn border_inline_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_style\nsketch border_inline_style","url":"sketch.html#border_inline_style"},{"doc":"sketch","title":"border_inline_width","content":"pub fn border_inline_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_inline_width\nsketch border_inline_width","url":"sketch.html#border_inline_width"},{"doc":"sketch","title":"border_inline_width_","content":"pub fn border_inline_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_inline_width_\nsketch border_inline_width_","url":"sketch.html#border_inline_width_"},{"doc":"sketch","title":"border_left","content":"pub fn border_left(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_left\nsketch border_left","url":"sketch.html#border_left"},{"doc":"sketch","title":"border_left_color","content":"pub fn border_left_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_left_color\nsketch border_left_color","url":"sketch.html#border_left_color"},{"doc":"sketch","title":"border_left_style","content":"pub fn border_left_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_left_style\nsketch border_left_style","url":"sketch.html#border_left_style"},{"doc":"sketch","title":"border_left_width","content":"pub fn border_left_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_left_width\nsketch border_left_width","url":"sketch.html#border_left_width"},{"doc":"sketch","title":"border_left_width_","content":"pub fn border_left_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_left_width_\nsketch border_left_width_","url":"sketch.html#border_left_width_"},{"doc":"sketch","title":"border_radius","content":"pub fn border_radius(border_radius: Size) -&gt; Style\n\nSynonyms:\nsketch.border_radius\nsketch border_radius","url":"sketch.html#border_radius"},{"doc":"sketch","title":"border_radius_","content":"pub fn border_radius_(border_radius: String) -&gt; Style\n\nSynonyms:\nsketch.border_radius_\nsketch border_radius_","url":"sketch.html#border_radius_"},{"doc":"sketch","title":"border_right","content":"pub fn border_right(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_right\nsketch border_right","url":"sketch.html#border_right"},{"doc":"sketch","title":"border_right_color","content":"pub fn border_right_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_right_color\nsketch border_right_color","url":"sketch.html#border_right_color"},{"doc":"sketch","title":"border_right_style","content":"pub fn border_right_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_right_style\nsketch border_right_style","url":"sketch.html#border_right_style"},{"doc":"sketch","title":"border_right_width","content":"pub fn border_right_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_right_width\nsketch border_right_width","url":"sketch.html#border_right_width"},{"doc":"sketch","title":"border_right_width_","content":"pub fn border_right_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_right_width_\nsketch border_right_width_","url":"sketch.html#border_right_width_"},{"doc":"sketch","title":"border_spacing","content":"pub fn border_spacing(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_spacing\nsketch border_spacing","url":"sketch.html#border_spacing"},{"doc":"sketch","title":"border_spacing_","content":"pub fn border_spacing_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_spacing_\nsketch border_spacing_","url":"sketch.html#border_spacing_"},{"doc":"sketch","title":"border_start_end_radius","content":"pub fn border_start_end_radius(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_start_end_radius\nsketch border_start_end_radius","url":"sketch.html#border_start_end_radius"},{"doc":"sketch","title":"border_start_start_radius","content":"pub fn border_start_start_radius(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_start_start_radius\nsketch border_start_start_radius","url":"sketch.html#border_start_start_radius"},{"doc":"sketch","title":"border_style","content":"pub fn border_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_style\nsketch border_style","url":"sketch.html#border_style"},{"doc":"sketch","title":"border_top","content":"pub fn border_top(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_top\nsketch border_top","url":"sketch.html#border_top"},{"doc":"sketch","title":"border_top_color","content":"pub fn border_top_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_top_color\nsketch border_top_color","url":"sketch.html#border_top_color"},{"doc":"sketch","title":"border_top_left_radius","content":"pub fn border_top_left_radius(\n  border_top_left_radius: Size,\n) -&gt; Style\n\nSynonyms:\nsketch.border_top_left_radius\nsketch border_top_left_radius","url":"sketch.html#border_top_left_radius"},{"doc":"sketch","title":"border_top_left_radius_","content":"pub fn border_top_left_radius_(\n  border_top_left_radius: String,\n) -&gt; Style\n\nSynonyms:\nsketch.border_top_left_radius_\nsketch border_top_left_radius_","url":"sketch.html#border_top_left_radius_"},{"doc":"sketch","title":"border_top_right_radius","content":"pub fn border_top_right_radius(\n  border_top_right_radius: Size,\n) -&gt; Style\n\nSynonyms:\nsketch.border_top_right_radius\nsketch border_top_right_radius","url":"sketch.html#border_top_right_radius"},{"doc":"sketch","title":"border_top_right_radius_","content":"pub fn border_top_right_radius_(\n  border_top_right_radius: String,\n) -&gt; Style\n\nSynonyms:\nsketch.border_top_right_radius_\nsketch border_top_right_radius_","url":"sketch.html#border_top_right_radius_"},{"doc":"sketch","title":"border_top_style","content":"pub fn border_top_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_top_style\nsketch border_top_style","url":"sketch.html#border_top_style"},{"doc":"sketch","title":"border_top_width","content":"pub fn border_top_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_top_width\nsketch border_top_width","url":"sketch.html#border_top_width"},{"doc":"sketch","title":"border_top_width_","content":"pub fn border_top_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_top_width_\nsketch border_top_width_","url":"sketch.html#border_top_width_"},{"doc":"sketch","title":"border_width","content":"pub fn border_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.border_width\nsketch border_width","url":"sketch.html#border_width"},{"doc":"sketch","title":"border_width_","content":"pub fn border_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.border_width_\nsketch border_width_","url":"sketch.html#border_width_"},{"doc":"sketch","title":"bottom","content":"pub fn bottom(size: Size) -&gt; Style\n\nSynonyms:\nsketch.bottom\nsketch bottom","url":"sketch.html#bottom"},{"doc":"sketch","title":"bottom_","content":"pub fn bottom_(size: String) -&gt; Style\n\nSynonyms:\nsketch.bottom_\nsketch bottom_","url":"sketch.html#bottom_"},{"doc":"sketch","title":"box_shadow","content":"pub fn box_shadow(box_shadow: String) -&gt; Style\n\nSynonyms:\nsketch.box_shadow\nsketch box_shadow","url":"sketch.html#box_shadow"},{"doc":"sketch","title":"box_sizing","content":"pub fn box_sizing(box_sizing: String) -&gt; Style\n\nSynonyms:\nsketch.box_sizing\nsketch box_sizing","url":"sketch.html#box_sizing"},{"doc":"sketch","title":"cache","content":"pub fn cache(strategy strategy: Strategy) -&gt; Result(Cache, Nil)\n Create a cache, managing the styles. You can instanciate as much cache as\n you want, if you need to manage different stylesheets.\n Instanciating an `Ephemeral` _always_ succeed.\nSynonyms:\nsketch.cache\nsketch cache","url":"sketch.html#cache"},{"doc":"sketch","title":"caption_side","content":"pub fn caption_side(value: String) -&gt; Style\n\nSynonyms:\nsketch.caption_side\nsketch caption_side","url":"sketch.html#caption_side"},{"doc":"sketch","title":"caret_color","content":"pub fn caret_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.caret_color\nsketch caret_color","url":"sketch.html#caret_color"},{"doc":"sketch","title":"checked","content":"pub fn checked(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.checked\nsketch checked","url":"sketch.html#checked"},{"doc":"sketch","title":"class","content":"pub fn class(styles: List(Style)) -&gt; Class\n\nSynonyms:\nsketch.class\nsketch class","url":"sketch.html#class"},{"doc":"sketch","title":"class_name","content":"pub fn class_name(class: Class, cache: Cache) -&gt; #(Cache, String)\n Convert a `Class` to its proper class name, to use it anywhere in your\n application. It can have the form `class1` or `class1 class2` in case of\n classes composition.\nSynonyms:\nsketch.class_name\nsketch class_name","url":"sketch.html#class_name"},{"doc":"sketch","title":"clear","content":"pub fn clear(value: String) -&gt; Style\n\nSynonyms:\nsketch.clear\nsketch clear","url":"sketch.html#clear"},{"doc":"sketch","title":"clip_path","content":"pub fn clip_path(value: String) -&gt; Style\n\nSynonyms:\nsketch.clip_path\nsketch clip_path","url":"sketch.html#clip_path"},{"doc":"sketch","title":"color","content":"pub fn color(color: String) -&gt; Style\n\nSynonyms:\nsketch.color\nsketch color","url":"sketch.html#color"},{"doc":"sketch","title":"color_interpolation","content":"pub fn color_interpolation(value: String) -&gt; Style\n\nSynonyms:\nsketch.color_interpolation\nsketch color_interpolation","url":"sketch.html#color_interpolation"},{"doc":"sketch","title":"color_scheme","content":"pub fn color_scheme(value: String) -&gt; Style\n\nSynonyms:\nsketch.color_scheme\nsketch color_scheme","url":"sketch.html#color_scheme"},{"doc":"sketch","title":"column_count","content":"pub fn column_count(value: String) -&gt; Style\n\nSynonyms:\nsketch.column_count\nsketch column_count","url":"sketch.html#column_count"},{"doc":"sketch","title":"column_fill","content":"pub fn column_fill(value: String) -&gt; Style\n\nSynonyms:\nsketch.column_fill\nsketch column_fill","url":"sketch.html#column_fill"},{"doc":"sketch","title":"column_gap","content":"pub fn column_gap(column_gap: Size) -&gt; Style\n\nSynonyms:\nsketch.column_gap\nsketch column_gap","url":"sketch.html#column_gap"},{"doc":"sketch","title":"column_rule","content":"pub fn column_rule(value: String) -&gt; Style\n\nSynonyms:\nsketch.column_rule\nsketch column_rule","url":"sketch.html#column_rule"},{"doc":"sketch","title":"column_rule_color","content":"pub fn column_rule_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.column_rule_color\nsketch column_rule_color","url":"sketch.html#column_rule_color"},{"doc":"sketch","title":"column_rule_style","content":"pub fn column_rule_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.column_rule_style\nsketch column_rule_style","url":"sketch.html#column_rule_style"},{"doc":"sketch","title":"column_rule_width","content":"pub fn column_rule_width(value: String) -&gt; Style\n\nSynonyms:\nsketch.column_rule_width\nsketch column_rule_width","url":"sketch.html#column_rule_width"},{"doc":"sketch","title":"column_span","content":"pub fn column_span(value: String) -&gt; Style\n\nSynonyms:\nsketch.column_span\nsketch column_span","url":"sketch.html#column_span"},{"doc":"sketch","title":"column_width","content":"pub fn column_width(value: String) -&gt; Style\n\nSynonyms:\nsketch.column_width\nsketch column_width","url":"sketch.html#column_width"},{"doc":"sketch","title":"columns","content":"pub fn columns(value: String) -&gt; Style\n\nSynonyms:\nsketch.columns\nsketch columns","url":"sketch.html#columns"},{"doc":"sketch","title":"compose","content":"pub fn compose(class: Class) -&gt; Style\n Compose styles by inheriting class, and later overrides them.\n Works similarly to `composes` property in CSS modules.\nSynonyms:\nsketch.compose\nsketch compose","url":"sketch.html#compose"},{"doc":"sketch","title":"contain","content":"pub fn contain(value: String) -&gt; Style\n\nSynonyms:\nsketch.contain\nsketch contain","url":"sketch.html#contain"},{"doc":"sketch","title":"contain_intrinsic_block_size","content":"pub fn contain_intrinsic_block_size(value: Size) -&gt; Style\n\nSynonyms:\nsketch.contain_intrinsic_block_size\nsketch contain_intrinsic_block_size","url":"sketch.html#contain_intrinsic_block_size"},{"doc":"sketch","title":"contain_intrinsic_block_size_","content":"pub fn contain_intrinsic_block_size_(value: String) -&gt; Style\n\nSynonyms:\nsketch.contain_intrinsic_block_size_\nsketch contain_intrinsic_block_size_","url":"sketch.html#contain_intrinsic_block_size_"},{"doc":"sketch","title":"contain_intrinsic_height","content":"pub fn contain_intrinsic_height(value: Size) -&gt; Style\n\nSynonyms:\nsketch.contain_intrinsic_height\nsketch contain_intrinsic_height","url":"sketch.html#contain_intrinsic_height"},{"doc":"sketch","title":"contain_intrinsic_height_","content":"pub fn contain_intrinsic_height_(value: String) -&gt; Style\n\nSynonyms:\nsketch.contain_intrinsic_height_\nsketch contain_intrinsic_height_","url":"sketch.html#contain_intrinsic_height_"},{"doc":"sketch","title":"contain_intrinsic_inline_size","content":"pub fn contain_intrinsic_inline_size(value: Size) -&gt; Style\n\nSynonyms:\nsketch.contain_intrinsic_inline_size\nsketch contain_intrinsic_inline_size","url":"sketch.html#contain_intrinsic_inline_size"},{"doc":"sketch","title":"contain_intrinsic_inline_size_","content":"pub fn contain_intrinsic_inline_size_(value: String) -&gt; Style\n\nSynonyms:\nsketch.contain_intrinsic_inline_size_\nsketch contain_intrinsic_inline_size_","url":"sketch.html#contain_intrinsic_inline_size_"},{"doc":"sketch","title":"contain_intrinsic_size","content":"pub fn contain_intrinsic_size(value: Size) -&gt; Style\n\nSynonyms:\nsketch.contain_intrinsic_size\nsketch contain_intrinsic_size","url":"sketch.html#contain_intrinsic_size"},{"doc":"sketch","title":"contain_intrinsic_size_","content":"pub fn contain_intrinsic_size_(value: String) -&gt; Style\n\nSynonyms:\nsketch.contain_intrinsic_size_\nsketch contain_intrinsic_size_","url":"sketch.html#contain_intrinsic_size_"},{"doc":"sketch","title":"contain_intrinsic_width","content":"pub fn contain_intrinsic_width(value: Size) -&gt; Style\n\nSynonyms:\nsketch.contain_intrinsic_width\nsketch contain_intrinsic_width","url":"sketch.html#contain_intrinsic_width"},{"doc":"sketch","title":"contain_intrinsic_width_","content":"pub fn contain_intrinsic_width_(value: String) -&gt; Style\n\nSynonyms:\nsketch.contain_intrinsic_width_\nsketch contain_intrinsic_width_","url":"sketch.html#contain_intrinsic_width_"},{"doc":"sketch","title":"container","content":"pub fn container(value: String) -&gt; Style\n\nSynonyms:\nsketch.container\nsketch container","url":"sketch.html#container"},{"doc":"sketch","title":"container_name","content":"pub fn container_name(value: String) -&gt; Style\n\nSynonyms:\nsketch.container_name\nsketch container_name","url":"sketch.html#container_name"},{"doc":"sketch","title":"container_type","content":"pub fn container_type(value: String) -&gt; Style\n\nSynonyms:\nsketch.container_type\nsketch container_type","url":"sketch.html#container_type"},{"doc":"sketch","title":"content","content":"pub fn content(value: String) -&gt; Style\n\nSynonyms:\nsketch.content\nsketch content","url":"sketch.html#content"},{"doc":"sketch","title":"counter_increment","content":"pub fn counter_increment(value: String) -&gt; Style\n\nSynonyms:\nsketch.counter_increment\nsketch counter_increment","url":"sketch.html#counter_increment"},{"doc":"sketch","title":"counter_reset","content":"pub fn counter_reset(value: String) -&gt; Style\n\nSynonyms:\nsketch.counter_reset\nsketch counter_reset","url":"sketch.html#counter_reset"},{"doc":"sketch","title":"counter_set","content":"pub fn counter_set(value: String) -&gt; Style\n\nSynonyms:\nsketch.counter_set\nsketch counter_set","url":"sketch.html#counter_set"},{"doc":"sketch","title":"cursor","content":"pub fn cursor(cursor: String) -&gt; Style\n\nSynonyms:\nsketch.cursor\nsketch cursor","url":"sketch.html#cursor"},{"doc":"sketch","title":"cx","content":"pub fn cx(value: Size) -&gt; Style\n\nSynonyms:\nsketch.cx\nsketch cx","url":"sketch.html#cx"},{"doc":"sketch","title":"cx_","content":"pub fn cx_(value: String) -&gt; Style\n\nSynonyms:\nsketch.cx_\nsketch cx_","url":"sketch.html#cx_"},{"doc":"sketch","title":"cy","content":"pub fn cy(value: Size) -&gt; Style\n\nSynonyms:\nsketch.cy\nsketch cy","url":"sketch.html#cy"},{"doc":"sketch","title":"cy_","content":"pub fn cy_(value: String) -&gt; Style\n\nSynonyms:\nsketch.cy_\nsketch cy_","url":"sketch.html#cy_"},{"doc":"sketch","title":"direction","content":"pub fn direction(direction: String) -&gt; Style\n\nSynonyms:\nsketch.direction\nsketch direction","url":"sketch.html#direction"},{"doc":"sketch","title":"disabled","content":"pub fn disabled(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.disabled\nsketch disabled","url":"sketch.html#disabled"},{"doc":"sketch","title":"display","content":"pub fn display(display: String) -&gt; Style\n\nSynonyms:\nsketch.display\nsketch display","url":"sketch.html#display"},{"doc":"sketch","title":"empty_cells","content":"pub fn empty_cells(empty_cells: String) -&gt; Style\n\nSynonyms:\nsketch.empty_cells\nsketch empty_cells","url":"sketch.html#empty_cells"},{"doc":"sketch","title":"enabled","content":"pub fn enabled(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.enabled\nsketch enabled","url":"sketch.html#enabled"},{"doc":"sketch","title":"field_sizing","content":"pub fn field_sizing(field_sizing: String) -&gt; Style\n\nSynonyms:\nsketch.field_sizing\nsketch field_sizing","url":"sketch.html#field_sizing"},{"doc":"sketch","title":"filter","content":"pub fn filter(filter: String) -&gt; Style\n\nSynonyms:\nsketch.filter\nsketch filter","url":"sketch.html#filter"},{"doc":"sketch","title":"first_child","content":"pub fn first_child(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.first_child\nsketch first_child","url":"sketch.html#first_child"},{"doc":"sketch","title":"first_of_type","content":"pub fn first_of_type(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.first_of_type\nsketch first_of_type","url":"sketch.html#first_of_type"},{"doc":"sketch","title":"flex","content":"pub fn flex(flex: String) -&gt; Style\n\nSynonyms:\nsketch.flex\nsketch flex","url":"sketch.html#flex"},{"doc":"sketch","title":"flex_basis","content":"pub fn flex_basis(flex_basis: String) -&gt; Style\n\nSynonyms:\nsketch.flex_basis\nsketch flex_basis","url":"sketch.html#flex_basis"},{"doc":"sketch","title":"flex_direction","content":"pub fn flex_direction(flex_direction: String) -&gt; Style\n\nSynonyms:\nsketch.flex_direction\nsketch flex_direction","url":"sketch.html#flex_direction"},{"doc":"sketch","title":"flex_flow","content":"pub fn flex_flow(flex_flow: String) -&gt; Style\n\nSynonyms:\nsketch.flex_flow\nsketch flex_flow","url":"sketch.html#flex_flow"},{"doc":"sketch","title":"flex_grow","content":"pub fn flex_grow(flex_grow: Int) -&gt; Style\n\nSynonyms:\nsketch.flex_grow\nsketch flex_grow","url":"sketch.html#flex_grow"},{"doc":"sketch","title":"flex_grow_","content":"pub fn flex_grow_(flex_grow: String) -&gt; Style\n\nSynonyms:\nsketch.flex_grow_\nsketch flex_grow_","url":"sketch.html#flex_grow_"},{"doc":"sketch","title":"flex_shrink","content":"pub fn flex_shrink(flex_shrink: Float) -&gt; Style\n\nSynonyms:\nsketch.flex_shrink\nsketch flex_shrink","url":"sketch.html#flex_shrink"},{"doc":"sketch","title":"flex_shrink_","content":"pub fn flex_shrink_(flex_shrink: String) -&gt; Style\n\nSynonyms:\nsketch.flex_shrink_\nsketch flex_shrink_","url":"sketch.html#flex_shrink_"},{"doc":"sketch","title":"flex_wrap","content":"pub fn flex_wrap(flex_wrap: String) -&gt; Style\n\nSynonyms:\nsketch.flex_wrap\nsketch flex_wrap","url":"sketch.html#flex_wrap"},{"doc":"sketch","title":"float","content":"pub fn float(float: String) -&gt; Style\n\nSynonyms:\nsketch.float\nsketch float","url":"sketch.html#float"},{"doc":"sketch","title":"focus","content":"pub fn focus(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.focus\nsketch focus","url":"sketch.html#focus"},{"doc":"sketch","title":"focus_visible","content":"pub fn focus_visible(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.focus_visible\nsketch focus_visible","url":"sketch.html#focus_visible"},{"doc":"sketch","title":"focus_within","content":"pub fn focus_within(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.focus_within\nsketch focus_within","url":"sketch.html#focus_within"},{"doc":"sketch","title":"font","content":"pub fn font(value: String) -&gt; Style\n\nSynonyms:\nsketch.font\nsketch font","url":"sketch.html#font"},{"doc":"sketch","title":"font_family","content":"pub fn font_family(font_family: String) -&gt; Style\n\nSynonyms:\nsketch.font_family\nsketch font_family","url":"sketch.html#font_family"},{"doc":"sketch","title":"font_feature_settings","content":"pub fn font_feature_settings(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_feature_settings\nsketch font_feature_settings","url":"sketch.html#font_feature_settings"},{"doc":"sketch","title":"font_kerning","content":"pub fn font_kerning(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_kerning\nsketch font_kerning","url":"sketch.html#font_kerning"},{"doc":"sketch","title":"font_language_override","content":"pub fn font_language_override(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_language_override\nsketch font_language_override","url":"sketch.html#font_language_override"},{"doc":"sketch","title":"font_optical_sizing","content":"pub fn font_optical_sizing(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_optical_sizing\nsketch font_optical_sizing","url":"sketch.html#font_optical_sizing"},{"doc":"sketch","title":"font_palette","content":"pub fn font_palette(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_palette\nsketch font_palette","url":"sketch.html#font_palette"},{"doc":"sketch","title":"font_size","content":"pub fn font_size(font_size: Size) -&gt; Style\n\nSynonyms:\nsketch.font_size\nsketch font_size","url":"sketch.html#font_size"},{"doc":"sketch","title":"font_size_","content":"pub fn font_size_(font_size: String) -&gt; Style\n\nSynonyms:\nsketch.font_size_\nsketch font_size_","url":"sketch.html#font_size_"},{"doc":"sketch","title":"font_size_adjust","content":"pub fn font_size_adjust(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_size_adjust\nsketch font_size_adjust","url":"sketch.html#font_size_adjust"},{"doc":"sketch","title":"font_stretch","content":"pub fn font_stretch(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_stretch\nsketch font_stretch","url":"sketch.html#font_stretch"},{"doc":"sketch","title":"font_style","content":"pub fn font_style(font_style: String) -&gt; Style\n\nSynonyms:\nsketch.font_style\nsketch font_style","url":"sketch.html#font_style"},{"doc":"sketch","title":"font_synthesis","content":"pub fn font_synthesis(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_synthesis\nsketch font_synthesis","url":"sketch.html#font_synthesis"},{"doc":"sketch","title":"font_synthesis_position","content":"pub fn font_synthesis_position(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_synthesis_position\nsketch font_synthesis_position","url":"sketch.html#font_synthesis_position"},{"doc":"sketch","title":"font_synthesis_small_caps","content":"pub fn font_synthesis_small_caps(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_synthesis_small_caps\nsketch font_synthesis_small_caps","url":"sketch.html#font_synthesis_small_caps"},{"doc":"sketch","title":"font_synthesis_style","content":"pub fn font_synthesis_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_synthesis_style\nsketch font_synthesis_style","url":"sketch.html#font_synthesis_style"},{"doc":"sketch","title":"font_synthesis_weight","content":"pub fn font_synthesis_weight(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_synthesis_weight\nsketch font_synthesis_weight","url":"sketch.html#font_synthesis_weight"},{"doc":"sketch","title":"font_variant","content":"pub fn font_variant(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_variant\nsketch font_variant","url":"sketch.html#font_variant"},{"doc":"sketch","title":"font_variant_alternates","content":"pub fn font_variant_alternates(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_variant_alternates\nsketch font_variant_alternates","url":"sketch.html#font_variant_alternates"},{"doc":"sketch","title":"font_variant_caps","content":"pub fn font_variant_caps(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_variant_caps\nsketch font_variant_caps","url":"sketch.html#font_variant_caps"},{"doc":"sketch","title":"font_variant_east_asian","content":"pub fn font_variant_east_asian(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_variant_east_asian\nsketch font_variant_east_asian","url":"sketch.html#font_variant_east_asian"},{"doc":"sketch","title":"font_variant_emoji","content":"pub fn font_variant_emoji(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_variant_emoji\nsketch font_variant_emoji","url":"sketch.html#font_variant_emoji"},{"doc":"sketch","title":"font_variant_ligatures","content":"pub fn font_variant_ligatures(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_variant_ligatures\nsketch font_variant_ligatures","url":"sketch.html#font_variant_ligatures"},{"doc":"sketch","title":"font_variant_numeric","content":"pub fn font_variant_numeric(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_variant_numeric\nsketch font_variant_numeric","url":"sketch.html#font_variant_numeric"},{"doc":"sketch","title":"font_variant_position","content":"pub fn font_variant_position(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_variant_position\nsketch font_variant_position","url":"sketch.html#font_variant_position"},{"doc":"sketch","title":"font_variation_settings","content":"pub fn font_variation_settings(value: String) -&gt; Style\n\nSynonyms:\nsketch.font_variation_settings\nsketch font_variation_settings","url":"sketch.html#font_variation_settings"},{"doc":"sketch","title":"font_weight","content":"pub fn font_weight(font_weight: String) -&gt; Style\n\nSynonyms:\nsketch.font_weight\nsketch font_weight","url":"sketch.html#font_weight"},{"doc":"sketch","title":"forced_color_adjust","content":"pub fn forced_color_adjust(value: String) -&gt; Style\n\nSynonyms:\nsketch.forced_color_adjust\nsketch forced_color_adjust","url":"sketch.html#forced_color_adjust"},{"doc":"sketch","title":"gap","content":"pub fn gap(gap: Size) -&gt; Style\n\nSynonyms:\nsketch.gap\nsketch gap","url":"sketch.html#gap"},{"doc":"sketch","title":"gap_","content":"pub fn gap_(gap: String) -&gt; Style\n\nSynonyms:\nsketch.gap_\nsketch gap_","url":"sketch.html#gap_"},{"doc":"sketch","title":"grid_area","content":"pub fn grid_area(grid_area: String) -&gt; Style\n\nSynonyms:\nsketch.grid_area\nsketch grid_area","url":"sketch.html#grid_area"},{"doc":"sketch","title":"grid_auto_columns","content":"pub fn grid_auto_columns(grid_auto_columns: String) -&gt; Style\n\nSynonyms:\nsketch.grid_auto_columns\nsketch grid_auto_columns","url":"sketch.html#grid_auto_columns"},{"doc":"sketch","title":"grid_auto_flow","content":"pub fn grid_auto_flow(grid_auto_flow: String) -&gt; Style\n\nSynonyms:\nsketch.grid_auto_flow\nsketch grid_auto_flow","url":"sketch.html#grid_auto_flow"},{"doc":"sketch","title":"grid_auto_rows","content":"pub fn grid_auto_rows(grid_auto_rows: String) -&gt; Style\n\nSynonyms:\nsketch.grid_auto_rows\nsketch grid_auto_rows","url":"sketch.html#grid_auto_rows"},{"doc":"sketch","title":"grid_column","content":"pub fn grid_column(grid_column: String) -&gt; Style\n\nSynonyms:\nsketch.grid_column\nsketch grid_column","url":"sketch.html#grid_column"},{"doc":"sketch","title":"grid_column_end","content":"pub fn grid_column_end(grid_column: String) -&gt; Style\n\nSynonyms:\nsketch.grid_column_end\nsketch grid_column_end","url":"sketch.html#grid_column_end"},{"doc":"sketch","title":"grid_column_start","content":"pub fn grid_column_start(grid_column: String) -&gt; Style\n\nSynonyms:\nsketch.grid_column_start\nsketch grid_column_start","url":"sketch.html#grid_column_start"},{"doc":"sketch","title":"grid_row","content":"pub fn grid_row(grid_row: String) -&gt; Style\n\nSynonyms:\nsketch.grid_row\nsketch grid_row","url":"sketch.html#grid_row"},{"doc":"sketch","title":"grid_row_end","content":"pub fn grid_row_end(grid_row: String) -&gt; Style\n\nSynonyms:\nsketch.grid_row_end\nsketch grid_row_end","url":"sketch.html#grid_row_end"},{"doc":"sketch","title":"grid_row_start","content":"pub fn grid_row_start(grid_row: String) -&gt; Style\n\nSynonyms:\nsketch.grid_row_start\nsketch grid_row_start","url":"sketch.html#grid_row_start"},{"doc":"sketch","title":"grid_template","content":"pub fn grid_template(grid_template: String) -&gt; Style\n\nSynonyms:\nsketch.grid_template\nsketch grid_template","url":"sketch.html#grid_template"},{"doc":"sketch","title":"grid_template_areas","content":"pub fn grid_template_areas(\n  grid_template_areas: List(String),\n) -&gt; Style\n\nSynonyms:\nsketch.grid_template_areas\nsketch grid_template_areas","url":"sketch.html#grid_template_areas"},{"doc":"sketch","title":"grid_template_columns","content":"pub fn grid_template_columns(\n  grid_template_columns: String,\n) -&gt; Style\n\nSynonyms:\nsketch.grid_template_columns\nsketch grid_template_columns","url":"sketch.html#grid_template_columns"},{"doc":"sketch","title":"grid_template_rows","content":"pub fn grid_template_rows(grid_template_rows: String) -&gt; Style\n\nSynonyms:\nsketch.grid_template_rows\nsketch grid_template_rows","url":"sketch.html#grid_template_rows"},{"doc":"sketch","title":"hanging_punctuation","content":"pub fn hanging_punctuation(value: String) -&gt; Style\n\nSynonyms:\nsketch.hanging_punctuation\nsketch hanging_punctuation","url":"sketch.html#hanging_punctuation"},{"doc":"sketch","title":"height","content":"pub fn height(height: Size) -&gt; Style\n\nSynonyms:\nsketch.height\nsketch height","url":"sketch.html#height"},{"doc":"sketch","title":"height_","content":"pub fn height_(height: String) -&gt; Style\n\nSynonyms:\nsketch.height_\nsketch height_","url":"sketch.html#height_"},{"doc":"sketch","title":"hover","content":"pub fn hover(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.hover\nsketch hover","url":"sketch.html#hover"},{"doc":"sketch","title":"hyphenate_character","content":"pub fn hyphenate_character(value: String) -&gt; Style\n\nSynonyms:\nsketch.hyphenate_character\nsketch hyphenate_character","url":"sketch.html#hyphenate_character"},{"doc":"sketch","title":"hyphenate_limit_chars","content":"pub fn hyphenate_limit_chars(value: String) -&gt; Style\n\nSynonyms:\nsketch.hyphenate_limit_chars\nsketch hyphenate_limit_chars","url":"sketch.html#hyphenate_limit_chars"},{"doc":"sketch","title":"hyphens","content":"pub fn hyphens(value: String) -&gt; Style\n\nSynonyms:\nsketch.hyphens\nsketch hyphens","url":"sketch.html#hyphens"},{"doc":"sketch","title":"image_orientation","content":"pub fn image_orientation(value: String) -&gt; Style\n\nSynonyms:\nsketch.image_orientation\nsketch image_orientation","url":"sketch.html#image_orientation"},{"doc":"sketch","title":"image_rendering","content":"pub fn image_rendering(value: String) -&gt; Style\n\nSynonyms:\nsketch.image_rendering\nsketch image_rendering","url":"sketch.html#image_rendering"},{"doc":"sketch","title":"important","content":"pub fn important(style: Style) -&gt; Style\n Add an `!important` flag to any CSS property.\n It won&#39;t have any effect on non-property style, like media, etc. It will\n then act as the `identity` function.\nSynonyms:\nsketch.important\nsketch important","url":"sketch.html#important"},{"doc":"sketch","title":"inline_size","content":"pub fn inline_size(value: String) -&gt; Style\n\nSynonyms:\nsketch.inline_size\nsketch inline_size","url":"sketch.html#inline_size"},{"doc":"sketch","title":"inset","content":"pub fn inset(value: String) -&gt; Style\n\nSynonyms:\nsketch.inset\nsketch inset","url":"sketch.html#inset"},{"doc":"sketch","title":"inset_area","content":"pub fn inset_area(value: String) -&gt; Style\n\nSynonyms:\nsketch.inset_area\nsketch inset_area","url":"sketch.html#inset_area"},{"doc":"sketch","title":"inset_block","content":"pub fn inset_block(value: String) -&gt; Style\n\nSynonyms:\nsketch.inset_block\nsketch inset_block","url":"sketch.html#inset_block"},{"doc":"sketch","title":"inset_block_end","content":"pub fn inset_block_end(value: String) -&gt; Style\n\nSynonyms:\nsketch.inset_block_end\nsketch inset_block_end","url":"sketch.html#inset_block_end"},{"doc":"sketch","title":"inset_block_start","content":"pub fn inset_block_start(value: String) -&gt; Style\n\nSynonyms:\nsketch.inset_block_start\nsketch inset_block_start","url":"sketch.html#inset_block_start"},{"doc":"sketch","title":"inset_inline","content":"pub fn inset_inline(value: String) -&gt; Style\n\nSynonyms:\nsketch.inset_inline\nsketch inset_inline","url":"sketch.html#inset_inline"},{"doc":"sketch","title":"inset_inline_end","content":"pub fn inset_inline_end(value: String) -&gt; Style\n\nSynonyms:\nsketch.inset_inline_end\nsketch inset_inline_end","url":"sketch.html#inset_inline_end"},{"doc":"sketch","title":"inset_inline_start","content":"pub fn inset_inline_start(value: String) -&gt; Style\n\nSynonyms:\nsketch.inset_inline_start\nsketch inset_inline_start","url":"sketch.html#inset_inline_start"},{"doc":"sketch","title":"invalid","content":"pub fn invalid(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.invalid\nsketch invalid","url":"sketch.html#invalid"},{"doc":"sketch","title":"isolation","content":"pub fn isolation(value: String) -&gt; Style\n\nSynonyms:\nsketch.isolation\nsketch isolation","url":"sketch.html#isolation"},{"doc":"sketch","title":"justify_content","content":"pub fn justify_content(justify: String) -&gt; Style\n\nSynonyms:\nsketch.justify_content\nsketch justify_content","url":"sketch.html#justify_content"},{"doc":"sketch","title":"justify_items","content":"pub fn justify_items(justify: String) -&gt; Style\n\nSynonyms:\nsketch.justify_items\nsketch justify_items","url":"sketch.html#justify_items"},{"doc":"sketch","title":"justify_self","content":"pub fn justify_self(justify: String) -&gt; Style\n\nSynonyms:\nsketch.justify_self\nsketch justify_self","url":"sketch.html#justify_self"},{"doc":"sketch","title":"justify_tracks","content":"pub fn justify_tracks(justify: String) -&gt; Style\n\nSynonyms:\nsketch.justify_tracks\nsketch justify_tracks","url":"sketch.html#justify_tracks"},{"doc":"sketch","title":"last_child","content":"pub fn last_child(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.last_child\nsketch last_child","url":"sketch.html#last_child"},{"doc":"sketch","title":"last_of_type","content":"pub fn last_of_type(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.last_of_type\nsketch last_of_type","url":"sketch.html#last_of_type"},{"doc":"sketch","title":"left","content":"pub fn left(size: Size) -&gt; Style\n\nSynonyms:\nsketch.left\nsketch left","url":"sketch.html#left"},{"doc":"sketch","title":"left_","content":"pub fn left_(size: String) -&gt; Style\n\nSynonyms:\nsketch.left_\nsketch left_","url":"sketch.html#left_"},{"doc":"sketch","title":"letter_spacing","content":"pub fn letter_spacing(letter_spacing: String) -&gt; Style\n\nSynonyms:\nsketch.letter_spacing\nsketch letter_spacing","url":"sketch.html#letter_spacing"},{"doc":"sketch","title":"line_break","content":"pub fn line_break(line_break: String) -&gt; Style\n\nSynonyms:\nsketch.line_break\nsketch line_break","url":"sketch.html#line_break"},{"doc":"sketch","title":"line_height","content":"pub fn line_height(line_height: String) -&gt; Style\n\nSynonyms:\nsketch.line_height\nsketch line_height","url":"sketch.html#line_height"},{"doc":"sketch","title":"link","content":"pub fn link(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.link\nsketch link","url":"sketch.html#link"},{"doc":"sketch","title":"list_style","content":"pub fn list_style(list_style: String) -&gt; Style\n\nSynonyms:\nsketch.list_style\nsketch list_style","url":"sketch.html#list_style"},{"doc":"sketch","title":"list_style_image","content":"pub fn list_style_image(list_style_image: String) -&gt; Style\n\nSynonyms:\nsketch.list_style_image\nsketch list_style_image","url":"sketch.html#list_style_image"},{"doc":"sketch","title":"list_style_position","content":"pub fn list_style_position(list_style_position: String) -&gt; Style\n\nSynonyms:\nsketch.list_style_position\nsketch list_style_position","url":"sketch.html#list_style_position"},{"doc":"sketch","title":"list_style_type","content":"pub fn list_style_type(list_style_type: String) -&gt; Style\n\nSynonyms:\nsketch.list_style_type\nsketch list_style_type","url":"sketch.html#list_style_type"},{"doc":"sketch","title":"margin","content":"pub fn margin(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin\nsketch margin","url":"sketch.html#margin"},{"doc":"sketch","title":"margin_","content":"pub fn margin_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_\nsketch margin_","url":"sketch.html#margin_"},{"doc":"sketch","title":"margin_block","content":"pub fn margin_block(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin_block\nsketch margin_block","url":"sketch.html#margin_block"},{"doc":"sketch","title":"margin_block_","content":"pub fn margin_block_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_block_\nsketch margin_block_","url":"sketch.html#margin_block_"},{"doc":"sketch","title":"margin_block_end","content":"pub fn margin_block_end(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin_block_end\nsketch margin_block_end","url":"sketch.html#margin_block_end"},{"doc":"sketch","title":"margin_block_end_","content":"pub fn margin_block_end_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_block_end_\nsketch margin_block_end_","url":"sketch.html#margin_block_end_"},{"doc":"sketch","title":"margin_block_start","content":"pub fn margin_block_start(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin_block_start\nsketch margin_block_start","url":"sketch.html#margin_block_start"},{"doc":"sketch","title":"margin_block_start_","content":"pub fn margin_block_start_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_block_start_\nsketch margin_block_start_","url":"sketch.html#margin_block_start_"},{"doc":"sketch","title":"margin_bottom","content":"pub fn margin_bottom(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin_bottom\nsketch margin_bottom","url":"sketch.html#margin_bottom"},{"doc":"sketch","title":"margin_bottom_","content":"pub fn margin_bottom_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_bottom_\nsketch margin_bottom_","url":"sketch.html#margin_bottom_"},{"doc":"sketch","title":"margin_inline","content":"pub fn margin_inline(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin_inline\nsketch margin_inline","url":"sketch.html#margin_inline"},{"doc":"sketch","title":"margin_inline_","content":"pub fn margin_inline_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_inline_\nsketch margin_inline_","url":"sketch.html#margin_inline_"},{"doc":"sketch","title":"margin_inline_end","content":"pub fn margin_inline_end(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin_inline_end\nsketch margin_inline_end","url":"sketch.html#margin_inline_end"},{"doc":"sketch","title":"margin_inline_end_","content":"pub fn margin_inline_end_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_inline_end_\nsketch margin_inline_end_","url":"sketch.html#margin_inline_end_"},{"doc":"sketch","title":"margin_inline_start","content":"pub fn margin_inline_start(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin_inline_start\nsketch margin_inline_start","url":"sketch.html#margin_inline_start"},{"doc":"sketch","title":"margin_inline_start_","content":"pub fn margin_inline_start_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_inline_start_\nsketch margin_inline_start_","url":"sketch.html#margin_inline_start_"},{"doc":"sketch","title":"margin_left","content":"pub fn margin_left(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin_left\nsketch margin_left","url":"sketch.html#margin_left"},{"doc":"sketch","title":"margin_left_","content":"pub fn margin_left_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_left_\nsketch margin_left_","url":"sketch.html#margin_left_"},{"doc":"sketch","title":"margin_right","content":"pub fn margin_right(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin_right\nsketch margin_right","url":"sketch.html#margin_right"},{"doc":"sketch","title":"margin_right_","content":"pub fn margin_right_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_right_\nsketch margin_right_","url":"sketch.html#margin_right_"},{"doc":"sketch","title":"margin_top","content":"pub fn margin_top(margin: Size) -&gt; Style\n\nSynonyms:\nsketch.margin_top\nsketch margin_top","url":"sketch.html#margin_top"},{"doc":"sketch","title":"margin_top_","content":"pub fn margin_top_(margin: String) -&gt; Style\n\nSynonyms:\nsketch.margin_top_\nsketch margin_top_","url":"sketch.html#margin_top_"},{"doc":"sketch","title":"mask","content":"pub fn mask(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask\nsketch mask","url":"sketch.html#mask"},{"doc":"sketch","title":"mask_border","content":"pub fn mask_border(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_border\nsketch mask_border","url":"sketch.html#mask_border"},{"doc":"sketch","title":"mask_border_mode","content":"pub fn mask_border_mode(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_border_mode\nsketch mask_border_mode","url":"sketch.html#mask_border_mode"},{"doc":"sketch","title":"mask_border_outset","content":"pub fn mask_border_outset(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_border_outset\nsketch mask_border_outset","url":"sketch.html#mask_border_outset"},{"doc":"sketch","title":"mask_border_repeat","content":"pub fn mask_border_repeat(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_border_repeat\nsketch mask_border_repeat","url":"sketch.html#mask_border_repeat"},{"doc":"sketch","title":"mask_border_slice","content":"pub fn mask_border_slice(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_border_slice\nsketch mask_border_slice","url":"sketch.html#mask_border_slice"},{"doc":"sketch","title":"mask_border_source","content":"pub fn mask_border_source(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_border_source\nsketch mask_border_source","url":"sketch.html#mask_border_source"},{"doc":"sketch","title":"mask_border_width","content":"pub fn mask_border_width(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_border_width\nsketch mask_border_width","url":"sketch.html#mask_border_width"},{"doc":"sketch","title":"mask_clip","content":"pub fn mask_clip(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_clip\nsketch mask_clip","url":"sketch.html#mask_clip"},{"doc":"sketch","title":"mask_composite","content":"pub fn mask_composite(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_composite\nsketch mask_composite","url":"sketch.html#mask_composite"},{"doc":"sketch","title":"mask_image","content":"pub fn mask_image(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_image\nsketch mask_image","url":"sketch.html#mask_image"},{"doc":"sketch","title":"mask_mode","content":"pub fn mask_mode(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_mode\nsketch mask_mode","url":"sketch.html#mask_mode"},{"doc":"sketch","title":"mask_origin","content":"pub fn mask_origin(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_origin\nsketch mask_origin","url":"sketch.html#mask_origin"},{"doc":"sketch","title":"mask_position","content":"pub fn mask_position(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_position\nsketch mask_position","url":"sketch.html#mask_position"},{"doc":"sketch","title":"mask_repeat","content":"pub fn mask_repeat(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_repeat\nsketch mask_repeat","url":"sketch.html#mask_repeat"},{"doc":"sketch","title":"mask_size","content":"pub fn mask_size(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_size\nsketch mask_size","url":"sketch.html#mask_size"},{"doc":"sketch","title":"mask_type","content":"pub fn mask_type(value: String) -&gt; Style\n\nSynonyms:\nsketch.mask_type\nsketch mask_type","url":"sketch.html#mask_type"},{"doc":"sketch","title":"math_depth","content":"pub fn math_depth(value: String) -&gt; Style\n\nSynonyms:\nsketch.math_depth\nsketch math_depth","url":"sketch.html#math_depth"},{"doc":"sketch","title":"math_style","content":"pub fn math_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.math_style\nsketch math_style","url":"sketch.html#math_style"},{"doc":"sketch","title":"max_block_size","content":"pub fn max_block_size(value: Size) -&gt; Style\n\nSynonyms:\nsketch.max_block_size\nsketch max_block_size","url":"sketch.html#max_block_size"},{"doc":"sketch","title":"max_block_size_","content":"pub fn max_block_size_(value: String) -&gt; Style\n\nSynonyms:\nsketch.max_block_size_\nsketch max_block_size_","url":"sketch.html#max_block_size_"},{"doc":"sketch","title":"max_height","content":"pub fn max_height(height: Size) -&gt; Style\n\nSynonyms:\nsketch.max_height\nsketch max_height","url":"sketch.html#max_height"},{"doc":"sketch","title":"max_height_","content":"pub fn max_height_(height: String) -&gt; Style\n\nSynonyms:\nsketch.max_height_\nsketch max_height_","url":"sketch.html#max_height_"},{"doc":"sketch","title":"max_inline_size","content":"pub fn max_inline_size(value: Size) -&gt; Style\n\nSynonyms:\nsketch.max_inline_size\nsketch max_inline_size","url":"sketch.html#max_inline_size"},{"doc":"sketch","title":"max_inline_size_","content":"pub fn max_inline_size_(value: String) -&gt; Style\n\nSynonyms:\nsketch.max_inline_size_\nsketch max_inline_size_","url":"sketch.html#max_inline_size_"},{"doc":"sketch","title":"max_width","content":"pub fn max_width(width: Size) -&gt; Style\n\nSynonyms:\nsketch.max_width\nsketch max_width","url":"sketch.html#max_width"},{"doc":"sketch","title":"max_width_","content":"pub fn max_width_(width: String) -&gt; Style\n\nSynonyms:\nsketch.max_width_\nsketch max_width_","url":"sketch.html#max_width_"},{"doc":"sketch","title":"media","content":"pub fn media(query: Query, styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.media\nsketch media","url":"sketch.html#media"},{"doc":"sketch","title":"min_block_size","content":"pub fn min_block_size(value: Size) -&gt; Style\n\nSynonyms:\nsketch.min_block_size\nsketch min_block_size","url":"sketch.html#min_block_size"},{"doc":"sketch","title":"min_block_size_","content":"pub fn min_block_size_(value: String) -&gt; Style\n\nSynonyms:\nsketch.min_block_size_\nsketch min_block_size_","url":"sketch.html#min_block_size_"},{"doc":"sketch","title":"min_height","content":"pub fn min_height(height: Size) -&gt; Style\n\nSynonyms:\nsketch.min_height\nsketch min_height","url":"sketch.html#min_height"},{"doc":"sketch","title":"min_height_","content":"pub fn min_height_(height: String) -&gt; Style\n\nSynonyms:\nsketch.min_height_\nsketch min_height_","url":"sketch.html#min_height_"},{"doc":"sketch","title":"min_inline_size","content":"pub fn min_inline_size(value: Size) -&gt; Style\n\nSynonyms:\nsketch.min_inline_size\nsketch min_inline_size","url":"sketch.html#min_inline_size"},{"doc":"sketch","title":"min_inline_size_","content":"pub fn min_inline_size_(value: String) -&gt; Style\n\nSynonyms:\nsketch.min_inline_size_\nsketch min_inline_size_","url":"sketch.html#min_inline_size_"},{"doc":"sketch","title":"min_width","content":"pub fn min_width(width: Size) -&gt; Style\n\nSynonyms:\nsketch.min_width\nsketch min_width","url":"sketch.html#min_width"},{"doc":"sketch","title":"min_width_","content":"pub fn min_width_(width: String) -&gt; Style\n\nSynonyms:\nsketch.min_width_\nsketch min_width_","url":"sketch.html#min_width_"},{"doc":"sketch","title":"mix_blend_mode","content":"pub fn mix_blend_mode(value: String) -&gt; Style\n\nSynonyms:\nsketch.mix_blend_mode\nsketch mix_blend_mode","url":"sketch.html#mix_blend_mode"},{"doc":"sketch","title":"none","content":"pub fn none() -&gt; Style\n\nSynonyms:\nsketch.none\nsketch none","url":"sketch.html#none"},{"doc":"sketch","title":"nth_child","content":"pub fn nth_child(selector: String, styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.nth_child\nsketch nth_child","url":"sketch.html#nth_child"},{"doc":"sketch","title":"nth_last_child","content":"pub fn nth_last_child(\n  selector: String,\n  styles: List(Style),\n) -&gt; Style\n\nSynonyms:\nsketch.nth_last_child\nsketch nth_last_child","url":"sketch.html#nth_last_child"},{"doc":"sketch","title":"nth_last_of_type","content":"pub fn nth_last_of_type(\n  selector: String,\n  styles: List(Style),\n) -&gt; Style\n\nSynonyms:\nsketch.nth_last_of_type\nsketch nth_last_of_type","url":"sketch.html#nth_last_of_type"},{"doc":"sketch","title":"nth_of_type","content":"pub fn nth_of_type(\n  selector: String,\n  styles: List(Style),\n) -&gt; Style\n\nSynonyms:\nsketch.nth_of_type\nsketch nth_of_type","url":"sketch.html#nth_of_type"},{"doc":"sketch","title":"object_fit","content":"pub fn object_fit(object_fit: String) -&gt; Style\n\nSynonyms:\nsketch.object_fit\nsketch object_fit","url":"sketch.html#object_fit"},{"doc":"sketch","title":"object_position","content":"pub fn object_position(object_position: String) -&gt; Style\n\nSynonyms:\nsketch.object_position\nsketch object_position","url":"sketch.html#object_position"},{"doc":"sketch","title":"offset","content":"pub fn offset(offset: String) -&gt; Style\n\nSynonyms:\nsketch.offset\nsketch offset","url":"sketch.html#offset"},{"doc":"sketch","title":"offset_anchor","content":"pub fn offset_anchor(offset_anchor: String) -&gt; Style\n\nSynonyms:\nsketch.offset_anchor\nsketch offset_anchor","url":"sketch.html#offset_anchor"},{"doc":"sketch","title":"offset_distance","content":"pub fn offset_distance(offset_distance: String) -&gt; Style\n\nSynonyms:\nsketch.offset_distance\nsketch offset_distance","url":"sketch.html#offset_distance"},{"doc":"sketch","title":"offset_path","content":"pub fn offset_path(offset_path: String) -&gt; Style\n\nSynonyms:\nsketch.offset_path\nsketch offset_path","url":"sketch.html#offset_path"},{"doc":"sketch","title":"offset_position","content":"pub fn offset_position(offset_position: String) -&gt; Style\n\nSynonyms:\nsketch.offset_position\nsketch offset_position","url":"sketch.html#offset_position"},{"doc":"sketch","title":"offset_rotate","content":"pub fn offset_rotate(offset_rotate: String) -&gt; Style\n\nSynonyms:\nsketch.offset_rotate\nsketch offset_rotate","url":"sketch.html#offset_rotate"},{"doc":"sketch","title":"only_child","content":"pub fn only_child(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.only_child\nsketch only_child","url":"sketch.html#only_child"},{"doc":"sketch","title":"only_of_type","content":"pub fn only_of_type(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.only_of_type\nsketch only_of_type","url":"sketch.html#only_of_type"},{"doc":"sketch","title":"opacity","content":"pub fn opacity(opacity: Float) -&gt; Style\n\nSynonyms:\nsketch.opacity\nsketch opacity","url":"sketch.html#opacity"},{"doc":"sketch","title":"optional","content":"pub fn optional(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.optional\nsketch optional","url":"sketch.html#optional"},{"doc":"sketch","title":"order","content":"pub fn order(value: Int) -&gt; Style\n\nSynonyms:\nsketch.order\nsketch order","url":"sketch.html#order"},{"doc":"sketch","title":"order_","content":"pub fn order_(value: String) -&gt; Style\n\nSynonyms:\nsketch.order_\nsketch order_","url":"sketch.html#order_"},{"doc":"sketch","title":"orphans","content":"pub fn orphans(value: Int) -&gt; Style\n\nSynonyms:\nsketch.orphans\nsketch orphans","url":"sketch.html#orphans"},{"doc":"sketch","title":"orphans_","content":"pub fn orphans_(value: String) -&gt; Style\n\nSynonyms:\nsketch.orphans_\nsketch orphans_","url":"sketch.html#orphans_"},{"doc":"sketch","title":"outline","content":"pub fn outline(outline: String) -&gt; Style\n\nSynonyms:\nsketch.outline\nsketch outline","url":"sketch.html#outline"},{"doc":"sketch","title":"outline_color","content":"pub fn outline_color(outline_color: String) -&gt; Style\n\nSynonyms:\nsketch.outline_color\nsketch outline_color","url":"sketch.html#outline_color"},{"doc":"sketch","title":"outline_offset","content":"pub fn outline_offset(outline_offset: String) -&gt; Style\n\nSynonyms:\nsketch.outline_offset\nsketch outline_offset","url":"sketch.html#outline_offset"},{"doc":"sketch","title":"outline_style","content":"pub fn outline_style(outline_style: String) -&gt; Style\n\nSynonyms:\nsketch.outline_style\nsketch outline_style","url":"sketch.html#outline_style"},{"doc":"sketch","title":"outline_width","content":"pub fn outline_width(outline_width: String) -&gt; Style\n\nSynonyms:\nsketch.outline_width\nsketch outline_width","url":"sketch.html#outline_width"},{"doc":"sketch","title":"overflow","content":"pub fn overflow(overflow: String) -&gt; Style\n\nSynonyms:\nsketch.overflow\nsketch overflow","url":"sketch.html#overflow"},{"doc":"sketch","title":"overflow_anchor","content":"pub fn overflow_anchor(overflow_anchor: String) -&gt; Style\n\nSynonyms:\nsketch.overflow_anchor\nsketch overflow_anchor","url":"sketch.html#overflow_anchor"},{"doc":"sketch","title":"overflow_block","content":"pub fn overflow_block(overflow_block: String) -&gt; Style\n\nSynonyms:\nsketch.overflow_block\nsketch overflow_block","url":"sketch.html#overflow_block"},{"doc":"sketch","title":"overflow_clip_margin","content":"pub fn overflow_clip_margin(\n  overflow_clip_margin: String,\n) -&gt; Style\n\nSynonyms:\nsketch.overflow_clip_margin\nsketch overflow_clip_margin","url":"sketch.html#overflow_clip_margin"},{"doc":"sketch","title":"overflow_inline","content":"pub fn overflow_inline(overflow_inline: String) -&gt; Style\n\nSynonyms:\nsketch.overflow_inline\nsketch overflow_inline","url":"sketch.html#overflow_inline"},{"doc":"sketch","title":"overflow_wrap","content":"pub fn overflow_wrap(overflow_wrap: String) -&gt; Style\n\nSynonyms:\nsketch.overflow_wrap\nsketch overflow_wrap","url":"sketch.html#overflow_wrap"},{"doc":"sketch","title":"overflow_x","content":"pub fn overflow_x(overflow_x: String) -&gt; Style\n\nSynonyms:\nsketch.overflow_x\nsketch overflow_x","url":"sketch.html#overflow_x"},{"doc":"sketch","title":"overflow_y","content":"pub fn overflow_y(overflow_y: String) -&gt; Style\n\nSynonyms:\nsketch.overflow_y\nsketch overflow_y","url":"sketch.html#overflow_y"},{"doc":"sketch","title":"overscroll_behavior","content":"pub fn overscroll_behavior(value: String) -&gt; Style\n\nSynonyms:\nsketch.overscroll_behavior\nsketch overscroll_behavior","url":"sketch.html#overscroll_behavior"},{"doc":"sketch","title":"overscroll_behavior_block","content":"pub fn overscroll_behavior_block(value: String) -&gt; Style\n\nSynonyms:\nsketch.overscroll_behavior_block\nsketch overscroll_behavior_block","url":"sketch.html#overscroll_behavior_block"},{"doc":"sketch","title":"overscroll_behavior_inline","content":"pub fn overscroll_behavior_inline(value: String) -&gt; Style\n\nSynonyms:\nsketch.overscroll_behavior_inline\nsketch overscroll_behavior_inline","url":"sketch.html#overscroll_behavior_inline"},{"doc":"sketch","title":"overscroll_behavior_x","content":"pub fn overscroll_behavior_x(value: String) -&gt; Style\n\nSynonyms:\nsketch.overscroll_behavior_x\nsketch overscroll_behavior_x","url":"sketch.html#overscroll_behavior_x"},{"doc":"sketch","title":"overscroll_behavior_y","content":"pub fn overscroll_behavior_y(value: String) -&gt; Style\n\nSynonyms:\nsketch.overscroll_behavior_y\nsketch overscroll_behavior_y","url":"sketch.html#overscroll_behavior_y"},{"doc":"sketch","title":"padding","content":"pub fn padding(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding\nsketch padding","url":"sketch.html#padding"},{"doc":"sketch","title":"padding_","content":"pub fn padding_(padding: String) -&gt; Style\n\nSynonyms:\nsketch.padding_\nsketch padding_","url":"sketch.html#padding_"},{"doc":"sketch","title":"padding_block","content":"pub fn padding_block(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding_block\nsketch padding_block","url":"sketch.html#padding_block"},{"doc":"sketch","title":"padding_block_","content":"pub fn padding_block_(padding: String) -&gt; Style\n\nSynonyms:\nsketch.padding_block_\nsketch padding_block_","url":"sketch.html#padding_block_"},{"doc":"sketch","title":"padding_block_end","content":"pub fn padding_block_end(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding_block_end\nsketch padding_block_end","url":"sketch.html#padding_block_end"},{"doc":"sketch","title":"padding_block_end_","content":"pub fn padding_block_end_(padding: String) -&gt; Style\n\nSynonyms:\nsketch.padding_block_end_\nsketch padding_block_end_","url":"sketch.html#padding_block_end_"},{"doc":"sketch","title":"padding_block_start","content":"pub fn padding_block_start(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding_block_start\nsketch padding_block_start","url":"sketch.html#padding_block_start"},{"doc":"sketch","title":"padding_block_start_","content":"pub fn padding_block_start_(padding: String) -&gt; Style\n\nSynonyms:\nsketch.padding_block_start_\nsketch padding_block_start_","url":"sketch.html#padding_block_start_"},{"doc":"sketch","title":"padding_bottom","content":"pub fn padding_bottom(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding_bottom\nsketch padding_bottom","url":"sketch.html#padding_bottom"},{"doc":"sketch","title":"padding_inline","content":"pub fn padding_inline(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding_inline\nsketch padding_inline","url":"sketch.html#padding_inline"},{"doc":"sketch","title":"padding_inline_","content":"pub fn padding_inline_(padding: String) -&gt; Style\n\nSynonyms:\nsketch.padding_inline_\nsketch padding_inline_","url":"sketch.html#padding_inline_"},{"doc":"sketch","title":"padding_inline_end","content":"pub fn padding_inline_end(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding_inline_end\nsketch padding_inline_end","url":"sketch.html#padding_inline_end"},{"doc":"sketch","title":"padding_inline_end_","content":"pub fn padding_inline_end_(padding: String) -&gt; Style\n\nSynonyms:\nsketch.padding_inline_end_\nsketch padding_inline_end_","url":"sketch.html#padding_inline_end_"},{"doc":"sketch","title":"padding_inline_start","content":"pub fn padding_inline_start(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding_inline_start\nsketch padding_inline_start","url":"sketch.html#padding_inline_start"},{"doc":"sketch","title":"padding_inline_start_","content":"pub fn padding_inline_start_(padding: String) -&gt; Style\n\nSynonyms:\nsketch.padding_inline_start_\nsketch padding_inline_start_","url":"sketch.html#padding_inline_start_"},{"doc":"sketch","title":"padding_left","content":"pub fn padding_left(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding_left\nsketch padding_left","url":"sketch.html#padding_left"},{"doc":"sketch","title":"padding_right","content":"pub fn padding_right(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding_right\nsketch padding_right","url":"sketch.html#padding_right"},{"doc":"sketch","title":"padding_top","content":"pub fn padding_top(padding: Size) -&gt; Style\n\nSynonyms:\nsketch.padding_top\nsketch padding_top","url":"sketch.html#padding_top"},{"doc":"sketch","title":"page","content":"pub fn page(value: String) -&gt; Style\n\nSynonyms:\nsketch.page\nsketch page","url":"sketch.html#page"},{"doc":"sketch","title":"page_break_after","content":"pub fn page_break_after(value: String) -&gt; Style\n\nSynonyms:\nsketch.page_break_after\nsketch page_break_after","url":"sketch.html#page_break_after"},{"doc":"sketch","title":"page_break_before","content":"pub fn page_break_before(value: String) -&gt; Style\n\nSynonyms:\nsketch.page_break_before\nsketch page_break_before","url":"sketch.html#page_break_before"},{"doc":"sketch","title":"page_break_inside","content":"pub fn page_break_inside(value: String) -&gt; Style\n\nSynonyms:\nsketch.page_break_inside\nsketch page_break_inside","url":"sketch.html#page_break_inside"},{"doc":"sketch","title":"paint_order","content":"pub fn paint_order(value: String) -&gt; Style\n\nSynonyms:\nsketch.paint_order\nsketch paint_order","url":"sketch.html#paint_order"},{"doc":"sketch","title":"perspective","content":"pub fn perspective(value: String) -&gt; Style\n\nSynonyms:\nsketch.perspective\nsketch perspective","url":"sketch.html#perspective"},{"doc":"sketch","title":"perspective_origin","content":"pub fn perspective_origin(value: String) -&gt; Style\n\nSynonyms:\nsketch.perspective_origin\nsketch perspective_origin","url":"sketch.html#perspective_origin"},{"doc":"sketch","title":"place_content","content":"pub fn place_content(place: String) -&gt; Style\n\nSynonyms:\nsketch.place_content\nsketch place_content","url":"sketch.html#place_content"},{"doc":"sketch","title":"place_items","content":"pub fn place_items(place: String) -&gt; Style\n\nSynonyms:\nsketch.place_items\nsketch place_items","url":"sketch.html#place_items"},{"doc":"sketch","title":"place_self","content":"pub fn place_self(place: String) -&gt; Style\n\nSynonyms:\nsketch.place_self\nsketch place_self","url":"sketch.html#place_self"},{"doc":"sketch","title":"placeholder","content":"pub fn placeholder(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.placeholder\nsketch placeholder","url":"sketch.html#placeholder"},{"doc":"sketch","title":"pointer_events","content":"pub fn pointer_events(pointer_events: String) -&gt; Style\n\nSynonyms:\nsketch.pointer_events\nsketch pointer_events","url":"sketch.html#pointer_events"},{"doc":"sketch","title":"position","content":"pub fn position(position: String) -&gt; Style\n\nSynonyms:\nsketch.position\nsketch position","url":"sketch.html#position"},{"doc":"sketch","title":"print_color_adjust","content":"pub fn print_color_adjust(print: String) -&gt; Style\n\nSynonyms:\nsketch.print_color_adjust\nsketch print_color_adjust","url":"sketch.html#print_color_adjust"},{"doc":"sketch","title":"property","content":"pub fn property(field: String, content: String) -&gt; Style\n\nSynonyms:\nsketch.property\nsketch property","url":"sketch.html#property"},{"doc":"sketch","title":"pseudo_selector","content":"pub fn pseudo_selector(\n  value: String,\n  styles: List(Style),\n) -&gt; Style\n\nSynonyms:\nsketch.pseudo_selector\nsketch pseudo_selector","url":"sketch.html#pseudo_selector"},{"doc":"sketch","title":"quotes","content":"pub fn quotes(quotes: String) -&gt; Style\n\nSynonyms:\nsketch.quotes\nsketch quotes","url":"sketch.html#quotes"},{"doc":"sketch","title":"r","content":"pub fn r(r: String) -&gt; Style\n\nSynonyms:\nsketch.r\nsketch r","url":"sketch.html#r"},{"doc":"sketch","title":"read_only","content":"pub fn read_only(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.read_only\nsketch read_only","url":"sketch.html#read_only"},{"doc":"sketch","title":"read_write","content":"pub fn read_write(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.read_write\nsketch read_write","url":"sketch.html#read_write"},{"doc":"sketch","title":"render","content":"pub fn render(cache: Cache) -&gt; String\n Render the content in the cache in proper CSS stylesheet.\nSynonyms:\nsketch.render\nsketch render","url":"sketch.html#render"},{"doc":"sketch","title":"required","content":"pub fn required(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.required\nsketch required","url":"sketch.html#required"},{"doc":"sketch","title":"resize","content":"pub fn resize(value: String) -&gt; Style\n\nSynonyms:\nsketch.resize\nsketch resize","url":"sketch.html#resize"},{"doc":"sketch","title":"right","content":"pub fn right(size: Size) -&gt; Style\n\nSynonyms:\nsketch.right\nsketch right","url":"sketch.html#right"},{"doc":"sketch","title":"right_","content":"pub fn right_(size: String) -&gt; Style\n\nSynonyms:\nsketch.right_\nsketch right_","url":"sketch.html#right_"},{"doc":"sketch","title":"rotate","content":"pub fn rotate(value: String) -&gt; Style\n\nSynonyms:\nsketch.rotate\nsketch rotate","url":"sketch.html#rotate"},{"doc":"sketch","title":"row_gap","content":"pub fn row_gap(row_gap: Size) -&gt; Style\n\nSynonyms:\nsketch.row_gap\nsketch row_gap","url":"sketch.html#row_gap"},{"doc":"sketch","title":"ruby_position","content":"pub fn ruby_position(value: String) -&gt; Style\n\nSynonyms:\nsketch.ruby_position\nsketch ruby_position","url":"sketch.html#ruby_position"},{"doc":"sketch","title":"rx","content":"pub fn rx(value: Size) -&gt; Style\n\nSynonyms:\nsketch.rx\nsketch rx","url":"sketch.html#rx"},{"doc":"sketch","title":"rx_","content":"pub fn rx_(value: String) -&gt; Style\n\nSynonyms:\nsketch.rx_\nsketch rx_","url":"sketch.html#rx_"},{"doc":"sketch","title":"ry","content":"pub fn ry(value: Size) -&gt; Style\n\nSynonyms:\nsketch.ry\nsketch ry","url":"sketch.html#ry"},{"doc":"sketch","title":"ry_","content":"pub fn ry_(value: String) -&gt; Style\n\nSynonyms:\nsketch.ry_\nsketch ry_","url":"sketch.html#ry_"},{"doc":"sketch","title":"scale","content":"pub fn scale(value: String) -&gt; Style\n\nSynonyms:\nsketch.scale\nsketch scale","url":"sketch.html#scale"},{"doc":"sketch","title":"scroll_behavior","content":"pub fn scroll_behavior(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_behavior\nsketch scroll_behavior","url":"sketch.html#scroll_behavior"},{"doc":"sketch","title":"scroll_margin","content":"pub fn scroll_margin(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin\nsketch scroll_margin","url":"sketch.html#scroll_margin"},{"doc":"sketch","title":"scroll_margin_","content":"pub fn scroll_margin_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_\nsketch scroll_margin_","url":"sketch.html#scroll_margin_"},{"doc":"sketch","title":"scroll_margin_block","content":"pub fn scroll_margin_block(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_block\nsketch scroll_margin_block","url":"sketch.html#scroll_margin_block"},{"doc":"sketch","title":"scroll_margin_block_","content":"pub fn scroll_margin_block_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_block_\nsketch scroll_margin_block_","url":"sketch.html#scroll_margin_block_"},{"doc":"sketch","title":"scroll_margin_block_end","content":"pub fn scroll_margin_block_end(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_block_end\nsketch scroll_margin_block_end","url":"sketch.html#scroll_margin_block_end"},{"doc":"sketch","title":"scroll_margin_block_end_","content":"pub fn scroll_margin_block_end_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_block_end_\nsketch scroll_margin_block_end_","url":"sketch.html#scroll_margin_block_end_"},{"doc":"sketch","title":"scroll_margin_block_start","content":"pub fn scroll_margin_block_start(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_block_start\nsketch scroll_margin_block_start","url":"sketch.html#scroll_margin_block_start"},{"doc":"sketch","title":"scroll_margin_block_start_","content":"pub fn scroll_margin_block_start_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_block_start_\nsketch scroll_margin_block_start_","url":"sketch.html#scroll_margin_block_start_"},{"doc":"sketch","title":"scroll_margin_bottom","content":"pub fn scroll_margin_bottom(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_bottom\nsketch scroll_margin_bottom","url":"sketch.html#scroll_margin_bottom"},{"doc":"sketch","title":"scroll_margin_bottom_","content":"pub fn scroll_margin_bottom_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_bottom_\nsketch scroll_margin_bottom_","url":"sketch.html#scroll_margin_bottom_"},{"doc":"sketch","title":"scroll_margin_inline","content":"pub fn scroll_margin_inline(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_inline\nsketch scroll_margin_inline","url":"sketch.html#scroll_margin_inline"},{"doc":"sketch","title":"scroll_margin_inline_","content":"pub fn scroll_margin_inline_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_inline_\nsketch scroll_margin_inline_","url":"sketch.html#scroll_margin_inline_"},{"doc":"sketch","title":"scroll_margin_inline_end","content":"pub fn scroll_margin_inline_end(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_inline_end\nsketch scroll_margin_inline_end","url":"sketch.html#scroll_margin_inline_end"},{"doc":"sketch","title":"scroll_margin_inline_end_","content":"pub fn scroll_margin_inline_end_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_inline_end_\nsketch scroll_margin_inline_end_","url":"sketch.html#scroll_margin_inline_end_"},{"doc":"sketch","title":"scroll_margin_inline_start","content":"pub fn scroll_margin_inline_start(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_inline_start\nsketch scroll_margin_inline_start","url":"sketch.html#scroll_margin_inline_start"},{"doc":"sketch","title":"scroll_margin_inline_start_","content":"pub fn scroll_margin_inline_start_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_inline_start_\nsketch scroll_margin_inline_start_","url":"sketch.html#scroll_margin_inline_start_"},{"doc":"sketch","title":"scroll_margin_left","content":"pub fn scroll_margin_left(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_left\nsketch scroll_margin_left","url":"sketch.html#scroll_margin_left"},{"doc":"sketch","title":"scroll_margin_left_","content":"pub fn scroll_margin_left_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_left_\nsketch scroll_margin_left_","url":"sketch.html#scroll_margin_left_"},{"doc":"sketch","title":"scroll_margin_right","content":"pub fn scroll_margin_right(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_right\nsketch scroll_margin_right","url":"sketch.html#scroll_margin_right"},{"doc":"sketch","title":"scroll_margin_right_","content":"pub fn scroll_margin_right_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_right_\nsketch scroll_margin_right_","url":"sketch.html#scroll_margin_right_"},{"doc":"sketch","title":"scroll_margin_top","content":"pub fn scroll_margin_top(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_top\nsketch scroll_margin_top","url":"sketch.html#scroll_margin_top"},{"doc":"sketch","title":"scroll_margin_top_","content":"pub fn scroll_margin_top_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_margin_top_\nsketch scroll_margin_top_","url":"sketch.html#scroll_margin_top_"},{"doc":"sketch","title":"scroll_padding","content":"pub fn scroll_padding(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding\nsketch scroll_padding","url":"sketch.html#scroll_padding"},{"doc":"sketch","title":"scroll_padding_","content":"pub fn scroll_padding_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_\nsketch scroll_padding_","url":"sketch.html#scroll_padding_"},{"doc":"sketch","title":"scroll_padding_block","content":"pub fn scroll_padding_block(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_block\nsketch scroll_padding_block","url":"sketch.html#scroll_padding_block"},{"doc":"sketch","title":"scroll_padding_block_","content":"pub fn scroll_padding_block_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_block_\nsketch scroll_padding_block_","url":"sketch.html#scroll_padding_block_"},{"doc":"sketch","title":"scroll_padding_block_end","content":"pub fn scroll_padding_block_end(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_block_end\nsketch scroll_padding_block_end","url":"sketch.html#scroll_padding_block_end"},{"doc":"sketch","title":"scroll_padding_block_end_","content":"pub fn scroll_padding_block_end_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_block_end_\nsketch scroll_padding_block_end_","url":"sketch.html#scroll_padding_block_end_"},{"doc":"sketch","title":"scroll_padding_block_start","content":"pub fn scroll_padding_block_start(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_block_start\nsketch scroll_padding_block_start","url":"sketch.html#scroll_padding_block_start"},{"doc":"sketch","title":"scroll_padding_block_start_","content":"pub fn scroll_padding_block_start_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_block_start_\nsketch scroll_padding_block_start_","url":"sketch.html#scroll_padding_block_start_"},{"doc":"sketch","title":"scroll_padding_bottom","content":"pub fn scroll_padding_bottom(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_bottom\nsketch scroll_padding_bottom","url":"sketch.html#scroll_padding_bottom"},{"doc":"sketch","title":"scroll_padding_bottom_","content":"pub fn scroll_padding_bottom_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_bottom_\nsketch scroll_padding_bottom_","url":"sketch.html#scroll_padding_bottom_"},{"doc":"sketch","title":"scroll_padding_inline","content":"pub fn scroll_padding_inline(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_inline\nsketch scroll_padding_inline","url":"sketch.html#scroll_padding_inline"},{"doc":"sketch","title":"scroll_padding_inline_","content":"pub fn scroll_padding_inline_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_inline_\nsketch scroll_padding_inline_","url":"sketch.html#scroll_padding_inline_"},{"doc":"sketch","title":"scroll_padding_inline_end","content":"pub fn scroll_padding_inline_end(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_inline_end\nsketch scroll_padding_inline_end","url":"sketch.html#scroll_padding_inline_end"},{"doc":"sketch","title":"scroll_padding_inline_end_","content":"pub fn scroll_padding_inline_end_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_inline_end_\nsketch scroll_padding_inline_end_","url":"sketch.html#scroll_padding_inline_end_"},{"doc":"sketch","title":"scroll_padding_inline_start","content":"pub fn scroll_padding_inline_start(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_inline_start\nsketch scroll_padding_inline_start","url":"sketch.html#scroll_padding_inline_start"},{"doc":"sketch","title":"scroll_padding_inline_start_","content":"pub fn scroll_padding_inline_start_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_inline_start_\nsketch scroll_padding_inline_start_","url":"sketch.html#scroll_padding_inline_start_"},{"doc":"sketch","title":"scroll_padding_left","content":"pub fn scroll_padding_left(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_left\nsketch scroll_padding_left","url":"sketch.html#scroll_padding_left"},{"doc":"sketch","title":"scroll_padding_left_","content":"pub fn scroll_padding_left_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_left_\nsketch scroll_padding_left_","url":"sketch.html#scroll_padding_left_"},{"doc":"sketch","title":"scroll_padding_right","content":"pub fn scroll_padding_right(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_right\nsketch scroll_padding_right","url":"sketch.html#scroll_padding_right"},{"doc":"sketch","title":"scroll_padding_right_","content":"pub fn scroll_padding_right_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_right_\nsketch scroll_padding_right_","url":"sketch.html#scroll_padding_right_"},{"doc":"sketch","title":"scroll_padding_top","content":"pub fn scroll_padding_top(value: Size) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_top\nsketch scroll_padding_top","url":"sketch.html#scroll_padding_top"},{"doc":"sketch","title":"scroll_padding_top_","content":"pub fn scroll_padding_top_(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_padding_top_\nsketch scroll_padding_top_","url":"sketch.html#scroll_padding_top_"},{"doc":"sketch","title":"scroll_snap_align","content":"pub fn scroll_snap_align(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_snap_align\nsketch scroll_snap_align","url":"sketch.html#scroll_snap_align"},{"doc":"sketch","title":"scroll_snap_stop","content":"pub fn scroll_snap_stop(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_snap_stop\nsketch scroll_snap_stop","url":"sketch.html#scroll_snap_stop"},{"doc":"sketch","title":"scroll_snap_type","content":"pub fn scroll_snap_type(value: String) -&gt; Style\n\nSynonyms:\nsketch.scroll_snap_type\nsketch scroll_snap_type","url":"sketch.html#scroll_snap_type"},{"doc":"sketch","title":"scrollbar_color","content":"pub fn scrollbar_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.scrollbar_color\nsketch scrollbar_color","url":"sketch.html#scrollbar_color"},{"doc":"sketch","title":"scrollbar_gutter","content":"pub fn scrollbar_gutter(value: String) -&gt; Style\n\nSynonyms:\nsketch.scrollbar_gutter\nsketch scrollbar_gutter","url":"sketch.html#scrollbar_gutter"},{"doc":"sketch","title":"scrollbar_width","content":"pub fn scrollbar_width(value: String) -&gt; Style\n\nSynonyms:\nsketch.scrollbar_width\nsketch scrollbar_width","url":"sketch.html#scrollbar_width"},{"doc":"sketch","title":"shape_image_threshold","content":"pub fn shape_image_threshold(value: Float) -&gt; Style\n\nSynonyms:\nsketch.shape_image_threshold\nsketch shape_image_threshold","url":"sketch.html#shape_image_threshold"},{"doc":"sketch","title":"shape_image_threshold_","content":"pub fn shape_image_threshold_(value: String) -&gt; Style\n\nSynonyms:\nsketch.shape_image_threshold_\nsketch shape_image_threshold_","url":"sketch.html#shape_image_threshold_"},{"doc":"sketch","title":"shape_margin","content":"pub fn shape_margin(value: Size) -&gt; Style\n\nSynonyms:\nsketch.shape_margin\nsketch shape_margin","url":"sketch.html#shape_margin"},{"doc":"sketch","title":"shape_margin_","content":"pub fn shape_margin_(value: String) -&gt; Style\n\nSynonyms:\nsketch.shape_margin_\nsketch shape_margin_","url":"sketch.html#shape_margin_"},{"doc":"sketch","title":"shape_outside","content":"pub fn shape_outside(value: String) -&gt; Style\n\nSynonyms:\nsketch.shape_outside\nsketch shape_outside","url":"sketch.html#shape_outside"},{"doc":"sketch","title":"tab_size","content":"pub fn tab_size(size: Size) -&gt; Style\n\nSynonyms:\nsketch.tab_size\nsketch tab_size","url":"sketch.html#tab_size"},{"doc":"sketch","title":"tab_size_","content":"pub fn tab_size_(size: String) -&gt; Style\n\nSynonyms:\nsketch.tab_size_\nsketch tab_size_","url":"sketch.html#tab_size_"},{"doc":"sketch","title":"table_layout","content":"pub fn table_layout(layout: String) -&gt; Style\n\nSynonyms:\nsketch.table_layout\nsketch table_layout","url":"sketch.html#table_layout"},{"doc":"sketch","title":"target","content":"pub fn target(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.target\nsketch target","url":"sketch.html#target"},{"doc":"sketch","title":"text_align","content":"pub fn text_align(text_align: String) -&gt; Style\n\nSynonyms:\nsketch.text_align\nsketch text_align","url":"sketch.html#text_align"},{"doc":"sketch","title":"text_align_last","content":"pub fn text_align_last(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_align_last\nsketch text_align_last","url":"sketch.html#text_align_last"},{"doc":"sketch","title":"text_combine_upright","content":"pub fn text_combine_upright(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_combine_upright\nsketch text_combine_upright","url":"sketch.html#text_combine_upright"},{"doc":"sketch","title":"text_decoration","content":"pub fn text_decoration(text_decoration: String) -&gt; Style\n\nSynonyms:\nsketch.text_decoration\nsketch text_decoration","url":"sketch.html#text_decoration"},{"doc":"sketch","title":"text_decoration_color","content":"pub fn text_decoration_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_decoration_color\nsketch text_decoration_color","url":"sketch.html#text_decoration_color"},{"doc":"sketch","title":"text_decoration_line","content":"pub fn text_decoration_line(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_decoration_line\nsketch text_decoration_line","url":"sketch.html#text_decoration_line"},{"doc":"sketch","title":"text_decoration_skip_ink","content":"pub fn text_decoration_skip_ink(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_decoration_skip_ink\nsketch text_decoration_skip_ink","url":"sketch.html#text_decoration_skip_ink"},{"doc":"sketch","title":"text_decoration_style","content":"pub fn text_decoration_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_decoration_style\nsketch text_decoration_style","url":"sketch.html#text_decoration_style"},{"doc":"sketch","title":"text_decoration_thickness","content":"pub fn text_decoration_thickness(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_decoration_thickness\nsketch text_decoration_thickness","url":"sketch.html#text_decoration_thickness"},{"doc":"sketch","title":"text_emphasis","content":"pub fn text_emphasis(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_emphasis\nsketch text_emphasis","url":"sketch.html#text_emphasis"},{"doc":"sketch","title":"text_emphasis_color","content":"pub fn text_emphasis_color(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_emphasis_color\nsketch text_emphasis_color","url":"sketch.html#text_emphasis_color"},{"doc":"sketch","title":"text_emphasis_position","content":"pub fn text_emphasis_position(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_emphasis_position\nsketch text_emphasis_position","url":"sketch.html#text_emphasis_position"},{"doc":"sketch","title":"text_emphasis_style","content":"pub fn text_emphasis_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_emphasis_style\nsketch text_emphasis_style","url":"sketch.html#text_emphasis_style"},{"doc":"sketch","title":"text_indent","content":"pub fn text_indent(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_indent\nsketch text_indent","url":"sketch.html#text_indent"},{"doc":"sketch","title":"text_justify","content":"pub fn text_justify(text_justify: String) -&gt; Style\n\nSynonyms:\nsketch.text_justify\nsketch text_justify","url":"sketch.html#text_justify"},{"doc":"sketch","title":"text_orientation","content":"pub fn text_orientation(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_orientation\nsketch text_orientation","url":"sketch.html#text_orientation"},{"doc":"sketch","title":"text_overflow","content":"pub fn text_overflow(text_overflow: String) -&gt; Style\n\nSynonyms:\nsketch.text_overflow\nsketch text_overflow","url":"sketch.html#text_overflow"},{"doc":"sketch","title":"text_rendering","content":"pub fn text_rendering(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_rendering\nsketch text_rendering","url":"sketch.html#text_rendering"},{"doc":"sketch","title":"text_shadow","content":"pub fn text_shadow(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_shadow\nsketch text_shadow","url":"sketch.html#text_shadow"},{"doc":"sketch","title":"text_transform","content":"pub fn text_transform(text_transform: String) -&gt; Style\n\nSynonyms:\nsketch.text_transform\nsketch text_transform","url":"sketch.html#text_transform"},{"doc":"sketch","title":"text_underline_offset","content":"pub fn text_underline_offset(value: Size) -&gt; Style\n\nSynonyms:\nsketch.text_underline_offset\nsketch text_underline_offset","url":"sketch.html#text_underline_offset"},{"doc":"sketch","title":"text_underline_offset_","content":"pub fn text_underline_offset_(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_underline_offset_\nsketch text_underline_offset_","url":"sketch.html#text_underline_offset_"},{"doc":"sketch","title":"text_underline_position","content":"pub fn text_underline_position(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_underline_position\nsketch text_underline_position","url":"sketch.html#text_underline_position"},{"doc":"sketch","title":"text_wrap","content":"pub fn text_wrap(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_wrap\nsketch text_wrap","url":"sketch.html#text_wrap"},{"doc":"sketch","title":"text_wrap_mode","content":"pub fn text_wrap_mode(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_wrap_mode\nsketch text_wrap_mode","url":"sketch.html#text_wrap_mode"},{"doc":"sketch","title":"text_wrap_style","content":"pub fn text_wrap_style(value: String) -&gt; Style\n\nSynonyms:\nsketch.text_wrap_style\nsketch text_wrap_style","url":"sketch.html#text_wrap_style"},{"doc":"sketch","title":"top","content":"pub fn top(size: Size) -&gt; Style\n\nSynonyms:\nsketch.top\nsketch top","url":"sketch.html#top"},{"doc":"sketch","title":"top_","content":"pub fn top_(size: String) -&gt; Style\n\nSynonyms:\nsketch.top_\nsketch top_","url":"sketch.html#top_"},{"doc":"sketch","title":"touch_action","content":"pub fn touch_action(value: String) -&gt; Style\n\nSynonyms:\nsketch.touch_action\nsketch touch_action","url":"sketch.html#touch_action"},{"doc":"sketch","title":"transform","content":"pub fn transform(transform: String) -&gt; Style\n\nSynonyms:\nsketch.transform\nsketch transform","url":"sketch.html#transform"},{"doc":"sketch","title":"transform_box","content":"pub fn transform_box(transform_box: String) -&gt; Style\n\nSynonyms:\nsketch.transform_box\nsketch transform_box","url":"sketch.html#transform_box"},{"doc":"sketch","title":"transform_origin","content":"pub fn transform_origin(transform_origin: String) -&gt; Style\n\nSynonyms:\nsketch.transform_origin\nsketch transform_origin","url":"sketch.html#transform_origin"},{"doc":"sketch","title":"transform_style","content":"pub fn transform_style(transform_style: String) -&gt; Style\n\nSynonyms:\nsketch.transform_style\nsketch transform_style","url":"sketch.html#transform_style"},{"doc":"sketch","title":"transition","content":"pub fn transition(transition: String) -&gt; Style\n\nSynonyms:\nsketch.transition\nsketch transition","url":"sketch.html#transition"},{"doc":"sketch","title":"transition_behavior","content":"pub fn transition_behavior(value: String) -&gt; Style\n\nSynonyms:\nsketch.transition_behavior\nsketch transition_behavior","url":"sketch.html#transition_behavior"},{"doc":"sketch","title":"transition_delay","content":"pub fn transition_delay(value: String) -&gt; Style\n\nSynonyms:\nsketch.transition_delay\nsketch transition_delay","url":"sketch.html#transition_delay"},{"doc":"sketch","title":"transition_duration","content":"pub fn transition_duration(value: String) -&gt; Style\n\nSynonyms:\nsketch.transition_duration\nsketch transition_duration","url":"sketch.html#transition_duration"},{"doc":"sketch","title":"transition_property","content":"pub fn transition_property(value: String) -&gt; Style\n\nSynonyms:\nsketch.transition_property\nsketch transition_property","url":"sketch.html#transition_property"},{"doc":"sketch","title":"transition_timing_function","content":"pub fn transition_timing_function(value: String) -&gt; Style\n\nSynonyms:\nsketch.transition_timing_function\nsketch transition_timing_function","url":"sketch.html#transition_timing_function"},{"doc":"sketch","title":"translate","content":"pub fn translate(translate: String) -&gt; Style\n\nSynonyms:\nsketch.translate\nsketch translate","url":"sketch.html#translate"},{"doc":"sketch","title":"unicode_bidi","content":"pub fn unicode_bidi(value: String) -&gt; Style\n\nSynonyms:\nsketch.unicode_bidi\nsketch unicode_bidi","url":"sketch.html#unicode_bidi"},{"doc":"sketch","title":"user_select","content":"pub fn user_select(user_select: String) -&gt; Style\n\nSynonyms:\nsketch.user_select\nsketch user_select","url":"sketch.html#user_select"},{"doc":"sketch","title":"valid","content":"pub fn valid(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.valid\nsketch valid","url":"sketch.html#valid"},{"doc":"sketch","title":"vertical_align","content":"pub fn vertical_align(value: String) -&gt; Style\n\nSynonyms:\nsketch.vertical_align\nsketch vertical_align","url":"sketch.html#vertical_align"},{"doc":"sketch","title":"visibility","content":"pub fn visibility(visibility: String) -&gt; Style\n\nSynonyms:\nsketch.visibility\nsketch visibility","url":"sketch.html#visibility"},{"doc":"sketch","title":"visited","content":"pub fn visited(styles: List(Style)) -&gt; Style\n\nSynonyms:\nsketch.visited\nsketch visited","url":"sketch.html#visited"},{"doc":"sketch","title":"white_space","content":"pub fn white_space(white_space: String) -&gt; Style\n\nSynonyms:\nsketch.white_space\nsketch white_space","url":"sketch.html#white_space"},{"doc":"sketch","title":"white_space_collapse","content":"pub fn white_space_collapse(\n  white_space_collapse: String,\n) -&gt; Style\n\nSynonyms:\nsketch.white_space_collapse\nsketch white_space_collapse","url":"sketch.html#white_space_collapse"},{"doc":"sketch","title":"widows","content":"pub fn widows(value: String) -&gt; Style\n\nSynonyms:\nsketch.widows\nsketch widows","url":"sketch.html#widows"},{"doc":"sketch","title":"width","content":"pub fn width(width: Size) -&gt; Style\n\nSynonyms:\nsketch.width\nsketch width","url":"sketch.html#width"},{"doc":"sketch","title":"width_","content":"pub fn width_(width: String) -&gt; Style\n\nSynonyms:\nsketch.width_\nsketch width_","url":"sketch.html#width_"},{"doc":"sketch","title":"will_change","content":"pub fn will_change(value: String) -&gt; Style\n\nSynonyms:\nsketch.will_change\nsketch will_change","url":"sketch.html#will_change"},{"doc":"sketch","title":"word_break","content":"pub fn word_break(word_break: String) -&gt; Style\n\nSynonyms:\nsketch.word_break\nsketch word_break","url":"sketch.html#word_break"},{"doc":"sketch","title":"word_spacing","content":"pub fn word_spacing(word_spacing: String) -&gt; Style\n\nSynonyms:\nsketch.word_spacing\nsketch word_spacing","url":"sketch.html#word_spacing"},{"doc":"sketch","title":"word_wrap","content":"pub fn word_wrap(word_wrap: String) -&gt; Style\n\nSynonyms:\nsketch.word_wrap\nsketch word_wrap","url":"sketch.html#word_wrap"},{"doc":"sketch","title":"writing_mode","content":"pub fn writing_mode(value: String) -&gt; Style\n\nSynonyms:\nsketch.writing_mode\nsketch writing_mode","url":"sketch.html#writing_mode"},{"doc":"sketch","title":"z_index","content":"pub fn z_index(z_index: Int) -&gt; Style\n\nSynonyms:\nsketch.z_index\nsketch z_index","url":"sketch.html#z_index"},{"doc":"sketch","title":"zoom","content":"pub fn zoom(value: String) -&gt; Style\n\nSynonyms:\nsketch.zoom\nsketch zoom","url":"sketch.html#zoom"},{"doc":"sketch","title":"sketch","content":" Want to know more about details? Go to the\n [additional docs](https://hexdocs.pm/sketch/internal-details.html)!","url":"sketch.html"},{"doc":"sketch/error","title":"SketchError","content":"pub type SketchError {\n  NotABrowser\n}\n\nNotABrowser\n\n\nSynonyms:\nsketch/error.SketchError\nsketch/error SketchError","url":"sketch/error.html#SketchError"},{"doc":"sketch/error","title":"sketch/error","content":" Defines standard error returned by sketch.","url":"sketch/error.html"}]);